@@ -64,9 +64,11 @@ class Blopex(package.Package):
           f = ['-I' + includes[0]]
         (result, output) = self.Link([],[],' '.join(l+f),code,' '.join(f),petsc.language)
         if result:
+          self.libflags = ' '.join(l)
+          self.includeflags = ' '.join(f)
           slepcconf.write('#define SLEPC_HAVE_BLOPEX 1\n')
-          slepcvars.write('BLOPEX_LIB = ' + ' '.join(l) + '\n')
-          slepcvars.write('BLOPEX_INCLUDE = ' + ' '.join(f) + '\n')
+          slepcvars.write('BLOPEX_LIB = ' + self.libflags + '\n')
+          slepcvars.write('BLOPEX_INCLUDE = ' + self.includeflags + '\n')
           self.havepackage = True
           self.packageflags = ' '.join(l+f)
           return
@@ -113,9 +115,11 @@ class Blopex(package.Package):
       self.log.Exit('Unable to link with downloaded BLOPEX')
 
     # Write configuration files
+    self.libflags = l
+    self.includeflags = f
     slepcconf.write('#define SLEPC_HAVE_BLOPEX 1\n')
-    slepcvars.write('BLOPEX_LIB = ' + l + '\n')
-    slepcvars.write('BLOPEX_INCLUDE = ' + f + '\n')
+    slepcvars.write('BLOPEX_LIB = ' + self.libflags + '\n')
+    slepcvars.write('BLOPEX_INCLUDE = ' + self.includeflags + '\n')
 
     self.havepackage = True
     self.packageflags = l+' '+f
