@@ -31,10 +31,10 @@ class PETSc(package.Package):
     conf += 'CC_FLAGS=' + self.cc_flags + '\n'
     if hasattr(self,'fc'):
       conf += 'FC=' + self.fc + '\n'
-      conf += 'FC_FLAGS=' + (self.fc_flags if hasattr(self,'fc_flags') else '') + '\n'
+      conf += 'FC_FLAGS=' + getattr(self,'fc_flags','') + '\n'
     if hasattr(self,'cxx'):
       conf += 'CXX=' + self.cxx + '\n'
-      conf += 'CXX_FLAGS=' + (self.cxx_flags if hasattr(self,'cxx_flags') else '') + '\n'
+      conf += 'CXX_FLAGS=' + getattr(self,'cxx_flags','') + '\n'
     conf += 'PETSc configure options:\n'
     args = sorted(set(self.configure_options.split()))
     conf += '\n'.join('    '+a for a in args) + '\n'
