@@ -18,7 +18,7 @@ class Primme(package.Package):
     self.packagetype    = 'source_c'
     self.installable    = True
     self.downloadable   = True
-    self.version        = '3.2'
+    self.version        = '3.2.3'
     self.url            = 'https://github.com/primme/primme/archive/v'+self.version+'.tar.gz'
     self.archive        = 'primme-'+self.version+'.tar.gz'
     self.supportssingle = True
@@ -86,9 +86,11 @@ class Primme(package.Package):
           f = []
         (result, output) = self.Link([],[],' '.join(l+f),code,' '.join(f),petsc.language)
         if result:
+          self.libflags = ' '.join(l)
+          self.includeflags = ' '.join(f)
           slepcconf.write('#define SLEPC_HAVE_PRIMME 1\n')
-          slepcvars.write('PRIMME_LIB = ' + ' '.join(l) + '\n')
-          slepcvars.write('PRIMME_INCLUDE = ' + ' '.join(f) + '\n')
+          slepcvars.write('PRIMME_LIB = ' + self.libflags + '\n')
+          slepcvars.write('PRIMME_INCLUDE = ' + self.includeflags + '\n')
           self.havepackage = True
           self.packageflags = ' '.join(l+f)
           self.location = includes[0] if self.packageincludes else i
@@ -109,7 +111,7 @@ class Primme(package.Package):
     cont += 'export SONAMELIBRARY = libprimme.'+petsc.sl_linker_suffix+'.'+self.version+'\n'
     cont += 'export CC            = '+petsc.cc+'\n'
     if hasattr(petsc,'fc'):
-      cont += 'export F77           = '+petsc.fc+'\n'
+      cont += 'export F77         = '+petsc.fc+'\n'
     cont += 'export DEFINES       = '
     if petsc.blaslapackmangling == 'underscore':
       cont += '-DF77UNDERSCORE '
@@ -151,9 +153,11 @@ class Primme(package.Package):
       self.log.Exit('Unable to link with downloaded PRIMME')
 
     # Write configuration files
+    self.libflags = l
+    self.includeflags = f
     slepcconf.write('#define SLEPC_HAVE_PRIMME 1\n')
-    slepcvars.write('PRIMME_LIB = ' + l + '\n')
-    slepcvars.write('PRIMME_INCLUDE = ' + f + '\n')
+    slepcvars.write('PRIMME_LIB = ' + self.libflags + '\n')
+    slepcvars.write('PRIMME_INCLUDE = ' + self.includeflags + '\n')
 
     self.location = incdir
     self.havepackage = True
