@@ -28,7 +28,7 @@ class SLEPc(package.Package):
     print('  --with-packages-build-dir=<dir>'.ljust(wd)+': Location to unpack and run the build process for downloaded packages')
     print('\nSLEPc:')
     print('  --prefix=<dir>'.ljust(wd)+': Specify location to install SLEPc (e.g., /usr/local)')
-    print('  --DATAFILESPATH=<dir>'.ljust(wd)+': Location of datafiles (available at https://slepc.upv.es/datafiles)')
+    print('  --DATAFILESPATH=<dir>'.ljust(wd)+': Location of datafiles (available at https://gitlab.com/slepc/datafiles)')
 
   def ProcessArgs(self,argdb):
     self.clean       = argdb.PopBool('with-clean')[0]
@@ -55,19 +55,25 @@ class SLEPc(package.Package):
     self.AddDefine(slepcconf,'PETSC_ARCH',petsc.arch)
     self.AddDefine(slepcconf,'DIR',slepc.dir)
     self.AddDefine(slepcconf,'LIB_DIR',os.path.join(slepc.prefixdir,'lib'))
+    libdir = os.path.join(slepc.prefixdir,'lib')
+    incdir = os.path.join(slepc.prefixdir,'include')
+    if petsc.buildsharedlib:
+      self.libflags = petsc.cc_linker_slflag + libdir + ' -L' + libdir
+    else:
+      self.libflags = '-L' + libdir
+    self.includeflags = '-I' + incdir
     if slepc.isrepo and slepc.gitrev != 'unknown':
       self.AddDefine(slepcconf,'VERSION_GIT',slepc.gitrev)
       self.AddDefine(slepcconf,'VERSION_DATE_GIT',slepc.gitdate)
       self.AddDefine(slepcconf,'VERSION_BRANCH_GIT',slepc.branch)
+    slepcvars.write('LIB_NAME_SUFFIX = '+petsc.lib_name_suffix+'\n')
     # Single library installation
     if petsc.singlelib:
-      slepcvars.write('SHLIBS = libslepc\n')
-      slepcvars.write('LIBNAME = '+os.path.join('${INSTALL_LIB_DIR}','libslepc.${AR_LIB_SUFFIX}')+'\n')
+      slepcvars.write('SHLIBS = libslepc${LIB_NAME_SUFFIX}\n')
+      slepcvars.write('LIBNAME = '+os.path.join('${INSTALL_LIB_DIR}','libslepc${LIB_NAME_SUFFIX}.${AR_LIB_SUFFIX}')+'\n')
       for module in ['SYS','EPS','SVD','PEP','NEP','MFN','LME']:
-        slepcvars.write('SLEPC_'+module+'_LIB = ${CC_LINKER_SLFLAG}${SLEPC_LIB_DIR} -L${SLEPC_LIB_DIR} -lslepc ${SLEPC_EXTERNAL_LIB}\n')
-      slepcvars.write('SLEPC_LIB = ${CC_LINKER_SLFLAG}${SLEPC_LIB_DIR} -L${SLEPC_LIB_DIR} -lslepc ${SLEPC_EXTERNAL_LIB}\n')
-    else:
-      slepcvars.write('SLEPC_LIB = ${CC_LINKER_SLFLAG}${SLEPC_LIB_DIR} -L${SLEPC_LIB_DIR} ${SLEPC_LIB_BASIC} ${SLEPC_EXTERNAL_LIB}\n')
+        slepcvars.write('SLEPC_'+module+'_LIB_NOPETSC = ${CC_LINKER_SLFLAG}${SLEPC_LIB_DIR} -L${SLEPC_LIB_DIR} -lslepc${LIB_NAME_SUFFIX} ${SLEPC_EXTERNAL_LIB_BASIC}\n')
+      slepcvars.write('SLEPC_LIB_NOPETSC = ${CC_LINKER_SLFLAG}${SLEPC_LIB_DIR} -L${SLEPC_LIB_DIR} -lslepc${LIB_NAME_SUFFIX} ${SLEPC_EXTERNAL_LIB_BASIC}\n')
 
   def ShowInfo(self):
     self.log.Println('\nSLEPc directory:\n  '+self.dir)
@@ -111,8 +117,8 @@ class SLEPc(package.Package):
 
     # Check whether this is a working copy of the repository
     self.isrepo = False
-    if os.path.exists(os.path.join(self.dir,'src','docs')):
-      self.log.write('This appears to be a repository clone - src/docs exists')
+    if os.path.exists(os.path.join(self.dir,'.mailmap')):
+      self.log.write('This appears to be a repository clone - .mailmap exists')
       self.isrepo = True
       if os.path.exists(os.path.join(self.dir,'.git')):
         self.log.write('.git directory exists')
