@@ -11,9 +11,12 @@
    Include all top-level SLEPc functionality
 */
 
+#pragma once
+
+/* MANSEC = Sys */
+
 #include <slepcsvd.h>
 #include <slepcpep.h>
 #include <slepcnep.h>
 #include <slepcmfn.h>
 #include <slepclme.h>
-
