@@ -11,7 +11,7 @@
 #pragma once
 
 #include <slepceps.h>
-#include <slepc/private/slepcimpl.h>
+#include <slepc/private/bvimpl.h>
 
 /* SUBMANSEC = EPS */
 
@@ -27,7 +27,7 @@ struct _EPSOps {
   PetscErrorCode (*solve)(EPS);
   PetscErrorCode (*setup)(EPS);
   PetscErrorCode (*setupsort)(EPS);
-  PetscErrorCode (*setfromoptions)(EPS,PetscOptionItems*);
+  PetscErrorCode (*setfromoptions)(EPS,PetscOptionItems);
   PetscErrorCode (*publishoptions)(EPS);
   PetscErrorCode (*destroy)(EPS);
   PetscErrorCode (*reset)(EPS);
@@ -68,7 +68,8 @@ typedef enum { EPS_FEATURE_BALANCE=1,       /* balancing */
                EPS_FEATURE_EXTRACTION=8,    /* extraction technique different from Ritz */
                EPS_FEATURE_CONVERGENCE=16,  /* convergence test selected by user */
                EPS_FEATURE_STOPPING=32,     /* stopping test */
-               EPS_FEATURE_TWOSIDED=64      /* two-sided variant */
+               EPS_FEATURE_THRESHOLD=64,    /* threshold stopping test */
+               EPS_FEATURE_TWOSIDED=128     /* two-sided variant */
              } EPSFeatureType;
 
 /*
@@ -85,6 +86,8 @@ struct _p_EPS {
   PetscInt       nds;              /* number of basis vectors of deflation space */
   PetscScalar    target;           /* target value */
   PetscReal      tol;              /* tolerance */
+  PetscReal      thres;            /* threshold */
+  PetscBool      threlative;       /* threshold is relative */
   EPSConv        conv;             /* convergence test */
   EPSStop        stop;             /* stopping test */
   EPSWhich       which;            /* which part of the spectrum to be sought */
@@ -100,20 +103,20 @@ struct _p_EPS {
   PetscBool      twosided;         /* whether to compute left eigenvectors (two-sided solver) */
 
   /*-------------- User-provided functions and contexts -----------------*/
-  PetscErrorCode (*converged)(EPS,PetscScalar,PetscScalar,PetscReal,PetscReal*,void*);
-  PetscErrorCode (*convergeduser)(EPS,PetscScalar,PetscScalar,PetscReal,PetscReal*,void*);
-  PetscErrorCode (*convergeddestroy)(void*);
-  PetscErrorCode (*stopping)(EPS,PetscInt,PetscInt,PetscInt,PetscInt,EPSConvergedReason*,void*);
-  PetscErrorCode (*stoppinguser)(EPS,PetscInt,PetscInt,PetscInt,PetscInt,EPSConvergedReason*,void*);
-  PetscErrorCode (*stoppingdestroy)(void*);
-  PetscErrorCode (*arbitrary)(PetscScalar,PetscScalar,Vec,Vec,PetscScalar*,PetscScalar*,void*);
-  void           *convergedctx;
-  void           *stoppingctx;
-  void           *arbitraryctx;
-  PetscErrorCode (*monitor[MAXEPSMONITORS])(EPS,PetscInt,PetscInt,PetscScalar*,PetscScalar*,PetscReal*,PetscInt,void*);
-  PetscErrorCode (*monitordestroy[MAXEPSMONITORS])(void**);
-  void           *monitorcontext[MAXEPSMONITORS];
-  PetscInt       numbermonitors;
+  EPSConvergenceTestFn      *converged;
+  EPSConvergenceTestFn      *convergeduser;
+  PetscCtxDestroyFn         *convergeddestroy;
+  EPSStoppingTestFn         *stopping;
+  EPSStoppingTestFn         *stoppinguser;
+  PetscCtxDestroyFn         *stoppingdestroy;
+  SlepcArbitrarySelectionFn *arbitrary;
+  void                      *convergedctx;
+  void                      *stoppingctx;
+  void                      *arbitraryctx;
+  EPSMonitorFn              *monitor[MAXEPSMONITORS];
+  PetscCtxDestroyFn         *monitordestroy[MAXEPSMONITORS];
+  void                      *monitorcontext[MAXEPSMONITORS];
+  PetscInt                  numbermonitors;
 
   /*----------------- Child objects and working data -------------------*/
   ST             st;               /* spectral transformation object */
@@ -144,6 +147,7 @@ struct _p_EPS {
   PetscBool      isgeneralized;
   PetscBool      ispositive;
   PetscBool      ishermitian;
+  PetscBool      isstructured;
   EPSConvergedReason reason;
 };
 
@@ -204,6 +208,15 @@ struct _p_EPS {
   } while (0)
 #define EPSCheckStandard(eps) EPSCheckStandardCondition(eps,PETSC_TRUE,"")
 
+/* EPSCheckNotStructured: the problem is not structured */
+#define EPSCheckNotStructuredCondition(eps,condition,msg) \
+  do { \
+    if (condition) { \
+      PetscCheck(!(eps)->isstructured,PetscObjectComm((PetscObject)(eps)),PETSC_ERR_SUP,"The solver '%s'%s does not provide support for structured eigenproblems",((PetscObject)(eps))->type_name,(msg)); \
+    } \
+  } while (0)
+#define EPSCheckNotStructured(eps) EPSCheckNotStructuredCondition(eps,PETSC_TRUE,"")
+
 /* EPSCheckSinvert: shift-and-invert ST */
 #define EPSCheckSinvertCondition(eps,condition,msg) \
   do { \
@@ -240,6 +253,7 @@ struct _p_EPS {
       PetscCheck(!((mask) & EPS_FEATURE_EXTRACTION) || (eps)->extraction==EPS_RITZ,PetscObjectComm((PetscObject)(eps)),PETSC_ERR_SUP,"The solver '%s'%s only supports Ritz extraction",((PetscObject)(eps))->type_name,(msg)); \
       PetscCheck(!((mask) & EPS_FEATURE_CONVERGENCE) || (eps)->converged==EPSConvergedRelative,PetscObjectComm((PetscObject)(eps)),PETSC_ERR_SUP,"The solver '%s'%s only supports the default convergence test",((PetscObject)(eps))->type_name,(msg)); \
       PetscCheck(!((mask) & EPS_FEATURE_STOPPING) || (eps)->stopping==EPSStoppingBasic,PetscObjectComm((PetscObject)(eps)),PETSC_ERR_SUP,"The solver '%s'%s only supports the default stopping test",((PetscObject)(eps))->type_name,(msg)); \
+      PetscCheck(!((mask) & EPS_FEATURE_THRESHOLD) || (eps)->stopping!=EPSStoppingThreshold,PetscObjectComm((PetscObject)(eps)),PETSC_ERR_SUP,"The solver '%s'%s does not support the threshold stopping test",((PetscObject)(eps))->type_name,(msg)); \
       PetscCheck(!((mask) & EPS_FEATURE_TWOSIDED) || !(eps)->twosided,PetscObjectComm((PetscObject)(eps)),PETSC_ERR_SUP,"The solver '%s'%s cannot compute left eigenvectors (no two-sided variant)",((PetscObject)(eps))->type_name,(msg)); \
     } \
   } while (0)
@@ -264,6 +278,25 @@ struct _p_EPS {
   } while (0)
 #define EPSCheckIgnored(eps,mask) EPSCheckIgnoredCondition(eps,mask,PETSC_TRUE,"")
 
+/*
+    EPSSetCtxThreshold - Fills EPSStoppingCtx with data needed for the threshold stopping test
+*/
+#define EPSSetCtxThreshold(eps,eigr,eigi,k) \
+  do { \
+    if (eps->stop==EPS_STOP_THRESHOLD && k) { \
+      PetscScalar __kr=eigr[k-1],__ki=eigi[k-1],__kr0=eigr[0],__ki0=eigi[0]; \
+      PetscCall(STBackTransform(eps->st,1,&__kr,&__ki)); \
+      PetscCall(STBackTransform(eps->st,1,&__kr0,&__ki0)); \
+      if (eps->which==EPS_LARGEST_MAGNITUDE || eps->which==EPS_SMALLEST_MAGNITUDE) { \
+        ((EPSStoppingCtx)eps->stoppingctx)->firstev = SlepcAbsEigenvalue(__kr0,__ki0); \
+        ((EPSStoppingCtx)eps->stoppingctx)->lastev  = SlepcAbsEigenvalue(__kr,__ki); \
+      } else { \
+        ((EPSStoppingCtx)eps->stoppingctx)->firstev = PetscRealPart(__kr0); \
+        ((EPSStoppingCtx)eps->stoppingctx)->lastev  = PetscRealPart(__kr); \
+      } \
+    } \
+  } while (0)
+
 /*
   EPS_SetInnerProduct - set B matrix for inner product if appropriate.
 */
@@ -276,6 +309,7 @@ static inline PetscErrorCode EPS_SetInnerProduct(EPS eps)
   if (eps->ispositive || (eps->isgeneralized && eps->ishermitian)) {
     PetscCall(STGetBilinearForm(eps->st,&B));
     PetscCall(BVSetMatrix(eps->V,B,PetscNot(eps->ispositive)));
+    if (eps->twosided) PetscCall(BVSetMatrix(eps->W,B,PetscNot(eps->ispositive)));
     PetscCall(MatDestroy(&B));
   } else PetscCall(BVSetMatrix(eps->V,NULL,PETSC_FALSE));
   PetscFunctionReturn(PETSC_SUCCESS);
@@ -320,8 +354,162 @@ static inline PetscErrorCode EPS_KSPSetOperators(KSP ksp,Mat A,Mat B)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*
+  EPS_GetActualConverged - Gets the actual value of nconv; in special cases the
+  number of available eigenvalues is larger than the computed ones
+*/
+static inline PetscErrorCode EPS_GetActualConverged(EPS eps,PetscInt *nconv)
+{
+  PetscFunctionBegin;
+  *nconv = eps->nconv;
+  if (eps->isstructured) {
+    if (eps->problem_type == EPS_BSE && (eps->which == EPS_SMALLEST_MAGNITUDE || eps->which == EPS_LARGEST_MAGNITUDE || eps->which == EPS_TARGET_MAGNITUDE)) *nconv *= 2;
+    if (eps->problem_type == EPS_HAMILT && (eps->which == EPS_SMALLEST_MAGNITUDE || eps->which == EPS_LARGEST_MAGNITUDE || eps->which == EPS_TARGET_MAGNITUDE)) *nconv *= 2;
+  }
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*
+  EPS_GetEigenvector - Gets the i-th eigenvector taking into account the case
+  where i exceeds the number of computed vectors (structure-preserving solver).
+  The argument V should be eps->V for right eigenvectors, eps->W for left ones.
+*/
+static inline PetscErrorCode EPS_GetEigenvector(EPS eps,BV V,PetscInt i,Vec Vr,Vec Vi)
+{
+  PetscInt  k;
+  Vec       v0,v1,w,w0,w1;
+  Mat       H;
+  IS        is[2];
+#if !defined(PETSC_USE_COMPLEX)
+  PetscInt  k0,k1,k2,iquad;
+  PetscReal nrm,nrmr=0.0,nrmi=0.0,sgn;
+#endif
+
+  PetscFunctionBegin;
+  if (!eps->isstructured) {
+    k = eps->perm[i];
+    PetscCall(BV_GetEigenvector(V,k,eps->eigi[k],Vr,Vi));
+  } else {
+    if (eps->problem_type == EPS_BSE && (eps->which == EPS_SMALLEST_MAGNITUDE || eps->which == EPS_LARGEST_MAGNITUDE || eps->which == EPS_TARGET_MAGNITUDE)) {
+      /* BSE problem, even index is +lambda, odd index is -lambda */
+      k = eps->perm[i/2];
+      if (i%2) {
+        /* eigenvector of -lambda is J*conj(X) where J=[0 I; I 0] and x is eigenvector of lambda */
+        PetscCall(VecDuplicate(Vr?Vr:Vi,&w));
+        PetscCall(STGetMatrix(eps->st,0,&H));
+        PetscCall(MatNestGetISs(H,is,NULL));
+        if (Vr) {
+          PetscCall(BV_GetEigenvector(V,k,eps->eigi[k],w,NULL));
+          PetscCall(VecConjugate(w));
+          PetscCall(VecGetSubVector(w,is[0],&w0));
+          PetscCall(VecGetSubVector(w,is[1],&w1));
+          PetscCall(VecGetSubVector(Vr,is[0],&v0));
+          PetscCall(VecGetSubVector(Vr,is[1],&v1));
+          PetscCall(VecCopy(w1,v0));
+          PetscCall(VecCopy(w0,v1));
+          PetscCall(VecRestoreSubVector(w,is[0],&w0));
+          PetscCall(VecRestoreSubVector(w,is[1],&w1));
+          PetscCall(VecRestoreSubVector(Vr,is[0],&v0));
+          PetscCall(VecRestoreSubVector(Vr,is[1],&v1));
+        }
+#if !defined(PETSC_USE_COMPLEX)
+        if (Vi) {
+          PetscCall(BV_GetEigenvector(V,k,eps->eigi[k],NULL,w));
+          PetscCall(VecScale(w,-1.0));
+          PetscCall(VecGetSubVector(w,is[0],&w0));
+          PetscCall(VecGetSubVector(w,is[1],&w1));
+          PetscCall(VecGetSubVector(Vi,is[0],&v0));
+          PetscCall(VecGetSubVector(Vi,is[1],&v1));
+          PetscCall(VecCopy(w1,v0));
+          PetscCall(VecCopy(w0,v1));
+          PetscCall(VecRestoreSubVector(w,is[0],&w0));
+          PetscCall(VecRestoreSubVector(w,is[1],&w1));
+          PetscCall(VecRestoreSubVector(Vi,is[0],&v0));
+          PetscCall(VecRestoreSubVector(Vi,is[1],&v1));
+        }
+#endif
+        PetscCall(VecDestroy(&w));
+      } else {
+        PetscCall(BV_GetEigenvector(V,k,eps->eigi[k],Vr,Vi));
+      }
+    } else if (eps->problem_type == EPS_HAMILT) {
+      k = eps->perm[i/2];
+#if !defined(PETSC_USE_COMPLEX)
+      if (eps->eigi[k]==0.0) { /* real eigenvalue */
+        if (Vr) {
+          PetscCall(BVCopyVec(V,k+eps->ncv/2+1,Vr));
+          PetscCall(BVGetColumn(V,k,&w));
+          PetscCall(VecAXPY(Vr,(i%2)?-eps->eigr[k]:eps->eigr[k],w));
+          PetscCall(BVRestoreColumn(V,k,&w));
+          PetscCall(VecNorm(Vr,NORM_2,&nrmr));
+        }
+        if (Vi) PetscCall(VecZeroEntries(Vi));
+        nrm = nrmr;
+      } else if (eps->eigr[k]==0.0 ) { /* purely imaginary eigenvalue */
+        if (Vr) {
+          PetscCall(BVCopyVec(V,k+eps->ncv/2+1,Vr));
+          PetscCall(VecNorm(Vr,NORM_2,&nrmr));
+        }
+        if (Vi) {
+          PetscCall(BVCopyVec(V,k,Vi));
+          PetscCall(VecScale(Vi,(i%2)?-eps->eigi[k]:eps->eigi[k]));
+          PetscCall(VecNorm(Vi,NORM_2,&nrmi));
+        }
+        nrm = SlepcAbs(nrmr,nrmi);
+      } else { /* quadruple eigenvalue (-conj(lambda),-lambda,lambda,conj(lambda)) */
+        iquad = i%2;  /* index within the 4 values */
+        if (i>=2) {
+          k2 = eps->perm[(i-2)/2];
+          if (eps->eigr[k]==eps->eigr[k2] && eps->eigi[k]==-eps->eigi[k2]) iquad += 2;
+        }
+        k0 = (iquad<2)? k: k2;
+        k1 = k0+1;
+        /* Vr+Vi*i obtained as eig*u+v where u=ur+ui*i is stored in cols k0 (ur) and k1 (ui) and
+           v=vr+vi*i is in cols shifted by ncv/2+1.
+           For lambda=eigr+eigi*i:
+            Vr+Vi*i = (eigr+eigi*i)(ur+ui*i) + vr+vi*i
+            Vr+Vi*i = eigr*(ur+ui*i) - eigi*ui+eigi*ur*i + vr+vi*i
+            Vr+Vi*i = eigr*ur-eigi*ui+vr + (eigi*ur+eigr*ui+vi)*i
+           For -conj(lambda): eigr, ui and vi have the signs changed
+           For       -lambda: eigr and eigi have the signs changed
+           For  conj(lambda): eigi, ui and vi have the signs changed   */
+        if (Vr) {
+          sgn = (iquad<2)? -1.0: 1.0;
+          PetscCall(BVCopyVec(V,k0,Vr));                  /* ur */
+          PetscCall(VecScale(Vr,sgn*eps->eigr[k0]));
+          PetscCall(BVGetColumn(V,k1,&w));                /* ui */
+          PetscCall(VecAXPY(Vr,-sgn*eps->eigi[k0],w));
+          PetscCall(BVRestoreColumn(V,k1,&w));
+          PetscCall(BVGetColumn(V,k0+eps->ncv/2+1,&w));   /* vr */
+          PetscCall(VecAXPY(Vr,1.0,w));
+          PetscCall(BVRestoreColumn(V,k0+eps->ncv/2+1,&w));
+          PetscCall(VecNorm(Vr,NORM_2,&nrmr));
+        }
+        if (Vi) {
+          sgn = (iquad%2)? -1.0: 1.0;
+          PetscCall(BVCopyVec(V,k0,Vi));                  /* ur */
+          PetscCall(VecScale(Vi,sgn*eps->eigi[k0]));
+          PetscCall(BVGetColumn(V,k1,&w));                /* ui */
+          PetscCall(VecAXPY(Vi,sgn*eps->eigr[k0],w));
+          PetscCall(BVRestoreColumn(V,k1,&w));
+          PetscCall(BVGetColumn(V,k1+eps->ncv/2+1,&w));   /* vi */
+          sgn = (iquad%3)? 1.0: -1.0;
+          PetscCall(VecAXPY(Vi,sgn,w));
+          PetscCall(BVRestoreColumn(V,k1+eps->ncv/2+1,&w));
+          PetscCall(VecNorm(Vi,NORM_2,&nrmi));
+        }
+        nrm = SlepcAbs(nrmr,nrmi);
+      }
+      if (Vr) PetscCall(VecScale(Vr,1.0/nrm));
+      if (Vi) PetscCall(VecScale(Vi,1.0/nrm));
+#endif
+    } else SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_LIB,"Inconsistent state");
+  }
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
 SLEPC_INTERN PetscErrorCode EPSSetWhichEigenpairs_Default(EPS);
-SLEPC_INTERN PetscErrorCode EPSSetDimensions_Default(EPS,PetscInt,PetscInt*,PetscInt*);
+SLEPC_INTERN PetscErrorCode EPSSetDimensions_Default(EPS,PetscInt*,PetscInt*,PetscInt*);
 SLEPC_INTERN PetscErrorCode EPSBackTransform_Default(EPS);
 SLEPC_INTERN PetscErrorCode EPSComputeVectors(EPS);
 SLEPC_INTERN PetscErrorCode EPSComputeVectors_Hermitian(EPS);
