@@ -26,21 +26,20 @@ SLEPC_EXTERN PetscErrorCode EPSInitializePackage(void);
 SLEPC_EXTERN PetscErrorCode EPSFinalizePackage(void);
 
 /*S
-    EPS - Abstract SLEPc object that manages all the eigenvalue
-    problem solvers.
+   EPS - SLEPc object that manages all the linear eigenvalue problem solvers.
 
-    Level: beginner
+   Level: beginner
 
-.seealso:  EPSCreate(), ST
+.seealso: [](ch:eps), `EPSCreate()`, `ST`
 S*/
 typedef struct _p_EPS* EPS;
 
 /*J
-    EPSType - String with the name of a SLEPc eigensolver
+   EPSType - String with the name of a linear eigensolver.
 
-    Level: beginner
+   Level: beginner
 
-.seealso: EPSSetType(), EPS
+.seealso: [](ch:eps), `EPSSetType()`, `EPS`
 J*/
 typedef const char *EPSType;
 #define EPSPOWER       "power"
@@ -69,11 +68,24 @@ typedef const char *EPSType;
 SLEPC_EXTERN PetscClassId EPS_CLASSID;
 
 /*E
-    EPSProblemType - Determines the type of eigenvalue problem
+   EPSProblemType - Determines the type of eigenvalue problem.
 
-    Level: beginner
+   Values:
++  `EPS_HEP`    - Hermitian
+.  `EPS_GHEP`   - generalized Hermitian
+.  `EPS_NHEP`   - non-Hermitian
+.  `EPS_GNHEP`  - generalized non-Hermitian
+.  `EPS_PGNHEP` - generalized non-Hermitian with positive (semi-)definite $B$
+.  `EPS_GHIEP`  - generalized Hermitian-indefinite
+.  `EPS_BSE`    - structured Bethe-Salpeter
+-  `EPS_HAMILT` - structured Hamiltonian
 
-.seealso: EPSSetProblemType(), EPSGetProblemType()
+   Note:
+   In real scalars, one should read the term Hermitian as symmetric.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSSetProblemType()`, `EPSGetProblemType()`
 E*/
 typedef enum { EPS_HEP    = 1,
                EPS_GHEP   = 2,
@@ -84,13 +96,142 @@ typedef enum { EPS_HEP    = 1,
                EPS_BSE    = 7,
                EPS_HAMILT = 8 } EPSProblemType;
 
+/*MC
+   EPS_HEP - A Hermitian eigenvalue problem.
+
+   Note:
+   The problem is formulated as $Ax=\lambda x$, where $A$ is real symmetric
+   or complex Hermitian.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSProblemType`, `EPSSetProblemType()`
+M*/
+
+/*MC
+   EPS_GHEP - A generalized Hermitian eigenvalue problem.
+
+   Note:
+   The problem is formulated as $Ax=\lambda Bx$, where $A$ and $B$ are real
+   symmetric or complex Hermitian, and $B$ is positive (semi-)definite.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSProblemType`, `EPSSetProblemType()`
+M*/
+
+/*MC
+   EPS_NHEP - A non-Hermitian eigenvalue problem.
+
+   Note:
+   The problem is formulated as $Ax=\lambda x$, where $A$ is non-symmetric
+   (or non-Hermitian).
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSProblemType`, `EPSSetProblemType()`
+M*/
+
+/*MC
+   EPS_GNHEP - A generalized non-Hermitian eigenvalue problem.
+
+   Note:
+   The problem is formulated as $Ax=\lambda Bx$, where $A$ or $B$ are
+   non-symmetric (or non-Hermitian).
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSProblemType`, `EPSSetProblemType()`
+M*/
+
+/*MC
+   EPS_PGNHEP - A generalized non-Hermitian eigenvalue problem with positive
+   (semi-)definite $B$.
+
+   Notes:
+   The problem is formulated as $Ax=\lambda Bx$, where $A$ is non-symmetric
+   (or non-Hermitian), but $B$ is symmetric (or Hermitian) and positive
+   (semi-)definite.
+
+   The problem will be solved with a non-Hermitian solver, but using an
+   inner product induced by matrix $B$.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSProblemType`, `EPSSetProblemType()`
+M*/
+
+/*MC
+   EPS_GHIEP - A generalized Hermitian-indefinite eigenvalue problem.
+
+   Notes:
+   The problem is formulated as $Ax=\lambda Bx$, where both $A$ and $B$ are
+   real symmetric or complex Hermitian, but $B$ is indefinite.
+
+   The solver will try to exploit the symmetry by using an indefinite
+   inner product, which may turn the computation numerically unstable.
+   To avoid this, solve the problem as non-Hermitian.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSProblemType`, `EPSSetProblemType()`
+M*/
+
+/*MC
+   EPS_BSE - A structured Bethe-Salpeter eigenvalue problem.
+
+   Notes:
+   The problem is formulated as $Hx=\lambda x$, where $H$ has a Bethe-Salpeter
+   structure,
+     $$H = \begin{bmatrix}
+        R & C \\
+        -C^* & -R^T
+        \end{bmatrix},$$
+   where $R$ is Hermitian and $C$ is complex symmetric. Can also be used in
+   the case of real matrices.
+
+   A description of the properties of this problem can be found in {cite:p}`Alv25`
+   and references therein.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), [](sec:structured), `EPSProblemType`, `EPSSetProblemType()`
+M*/
+
+/*MC
+   EPS_HAMILT - A structured Hamiltonian eigenvalue problem.
+
+   Note:
+   The problem is formulated as $Hx=\lambda x$, where $H$ has a Hamiltonian
+   structure,
+     $$H = \begin{bmatrix}
+        A & B \\
+        C & -A^*
+        \end{bmatrix},$$
+   where $A$, $B$ and $C$ are either real with $B=B^T$, $C=C^T$, or complex with
+   $B=B^*$, $C=C^*$.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), [](sec:structured), `EPSProblemType`, `EPSSetProblemType()`
+M*/
+
 /*E
-    EPSExtraction - Determines the type of extraction technique employed
-    by the eigensolver
+   EPSExtraction - Determines the type of extraction technique employed
+   by the eigensolver.
 
-    Level: advanced
+   Values:
++  `EPS_RITZ`              - Rayleigh-Ritz extraction
+.  `EPS_HARMONIC`          - harmonic Ritz extraction
+.  `EPS_HARMONIC_RELATIVE` - harmonic Ritz extraction relative to the eigenvalue
+.  `EPS_HARMONIC_RIGHT`    - harmonic Ritz extraction for rightmost eigenvalues
+.  `EPS_HARMONIC_LARGEST`  - harmonic Ritz extraction for largest magnitude (without target)
+.  `EPS_REFINED`           - refined Ritz extraction
+-  `EPS_REFINED_HARMONIC`  - refined harmonic Ritz extraction
 
-.seealso: EPSSetExtraction(), EPSGetExtraction()
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSSetExtraction()`, `EPSGetExtraction()`
 E*/
 typedef enum { EPS_RITZ,
                EPS_HARMONIC,
@@ -100,12 +241,121 @@ typedef enum { EPS_RITZ,
                EPS_REFINED,
                EPS_REFINED_HARMONIC } EPSExtraction;
 
+/*MC
+   EPS_RITZ - The standard Rayleigh-Ritz extraction.
+
+   Note:
+   This is the default way of computing eigenpair approximations from a
+   given subspace.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSExtraction`, `EPSSetExtraction()`
+M*/
+
+/*MC
+   EPS_HARMONIC - The harmonic Ritz extraction.
+
+   Notes:
+   This extraction method may provide better convergence when computing
+   interior eigenvalues close to a given target.
+
+   For the particular case of Krylov-Schur, a detailed description can
+   be found in {cite:p}`Rom09`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSExtraction`, `EPSSetExtraction()`, `EPSSetTarget()`
+M*/
+
+/*MC
+   EPS_HARMONIC_RELATIVE - The harmonic Ritz extraction relative to the eigenvalue.
+
+   Note:
+   This is a variation of `EPS_HARMONIC`, used in Davidson methods only.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSExtraction`, `EPSSetExtraction()`, `EPSSetTarget()`
+M*/
+
+/*MC
+   EPS_HARMONIC_RIGHT - The harmonic Ritz extraction for rightmost eigenvalues.
+
+   Note:
+   This is a variation of `EPS_HARMONIC`, used in Davidson methods only.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSExtraction`, `EPSSetExtraction()`, `EPSSetTarget()`
+M*/
+
+/*MC
+   EPS_HARMONIC_LARGEST - The harmonic Ritz extraction for largest magnitude
+   eigenvalues (without target).
+
+   Note:
+   This is a variation of `EPS_HARMONIC`, used in Davidson methods only.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSExtraction`, `EPSSetExtraction()`
+M*/
+
+/*MC
+   EPS_REFINED - The refined Ritz extraction method {cite:p}`Jia97`.
+
+   Note:
+   Currently implemented only in `EPSARNOLDI`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSExtraction`, `EPSSetExtraction()`
+M*/
+
+/*MC
+   EPS_REFINED_HARMONIC - The refined harmonic Ritz extraction.
+
+   Note:
+   This is a combination of `EPS_HARMONIC` and `EPS_REFINED`.
+
+   Developer Note:
+   Currently not implemented, reserved for future use.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSExtraction`, `EPSSetExtraction()`
+M*/
+
 /*E
-    EPSWhich - Determines which part of the spectrum is requested
+   EPSWhich - Determines which part of the spectrum is requested.
 
-    Level: intermediate
+   Values:
++  `EPS_LARGEST_MAGNITUDE`  - largest $|\lambda|$
+.  `EPS_SMALLEST_MAGNITUDE` - smallest $|\lambda|$
+.  `EPS_LARGEST_REAL`       - largest $\mathrm{Re}(\lambda)$
+.  `EPS_SMALLEST_REAL`      - smallest $\mathrm{Re}(\lambda)$
+.  `EPS_LARGEST_IMAGINARY`  - largest $\mathrm{Im}(\lambda)$
+.  `EPS_SMALLEST_IMAGINARY` - smallest $\mathrm{Im}(\lambda)$
+.  `EPS_TARGET_MAGNITUDE`   - smallest $|\lambda-\tau|$
+.  `EPS_TARGET_REAL`        - smallest $|\mathrm{Re}(\lambda-\tau)|$
+.  `EPS_TARGET_IMAGINARY`   - smallest $|\mathrm{Im}(\lambda-\tau)|$
+.  `EPS_ALL`                - all $\lambda\in[a,b]$ or $\lambda\in\Omega$
+-  `EPS_WHICH_USER`         - user-defined sorting criterion
 
-.seealso: EPSSetWhichEigenpairs(), EPSGetWhichEigenpairs()
+   Notes:
+   If SLEPc is compiled for real scalars `EPS_LARGEST_IMAGINARY` and
+   `EPS_SMALLEST_IMAGINARY` use the absolute value of the imaginary part
+   for eigenvalue selection.
+
+   The target $\tau$ is a scalar value provided with `EPSSetTarget()`.
+
+   The case `EPS_ALL` needs an interval $[a,b]$ given with `EPSSetInterval()`
+   or a region $\Omega$ specified with an `RG` object.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSSetWhichEigenpairs()`, `EPSSetTarget()`, `EPSSetInterval()`
 E*/
 typedef enum { EPS_LARGEST_MAGNITUDE  = 1,
                EPS_SMALLEST_MAGNITUDE = 2,
@@ -120,11 +370,17 @@ typedef enum { EPS_LARGEST_MAGNITUDE  = 1,
                EPS_WHICH_USER         = 11 } EPSWhich;
 
 /*E
-    EPSBalance - The type of balancing used for non-Hermitian problems
+   EPSBalance - The type of balancing used for non-Hermitian problems.
 
-    Level: intermediate
+   Values:
++  `EPS_BALANCE_NONE`    - no balancing matrix is used
+.  `EPS_BALANCE_ONESIDE` - balancing matrix $D$ is computed with a one-sided Krylov method
+.  `EPS_BALANCE_TWOSIDE` - balancing matrix $D$ is computed with a two-sided Krylov method
+-  `EPS_BALANCE_USER`    - use a balancing matrix $D$ provided by the user
 
-.seealso: EPSSetBalance()
+   Level: intermediate
+
+.seealso: [](ch:eps), [](sec:balancing), `EPSSetBalance()`
 E*/
 typedef enum { EPS_BALANCE_NONE,
                EPS_BALANCE_ONESIDE,
@@ -133,11 +389,16 @@ typedef enum { EPS_BALANCE_NONE,
 SLEPC_EXTERN const char *EPSBalanceTypes[];
 
 /*E
-    EPSErrorType - The error type used to assess accuracy of computed solutions
+   EPSErrorType - The error type used to assess the accuracy of computed solutions.
 
-    Level: intermediate
+   Values:
++  `EPS_ERROR_ABSOLUTE` - compute error bound as $\|r\|$
+.  `EPS_ERROR_RELATIVE` - compute error bound as $\|r\|/|\lambda|$
+-  `EPS_ERROR_BACKWARD` - compute error bound as $\|r\|/(\|A\|+|\lambda|\|B\|)$
 
-.seealso: EPSComputeError()
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSComputeError()`
 E*/
 typedef enum { EPS_ERROR_ABSOLUTE,
                EPS_ERROR_RELATIVE,
@@ -145,11 +406,17 @@ typedef enum { EPS_ERROR_ABSOLUTE,
 SLEPC_EXTERN const char *EPSErrorTypes[];
 
 /*E
-    EPSConv - Determines the convergence test
+   EPSConv - The convergence criterion to be used by the solver.
 
-    Level: intermediate
+   Values:
++  `EPS_CONV_ABS`  - absolute convergence criterion, $\|r\|$
+.  `EPS_CONV_REL`  - convergence criterion relative to eigenvalue, $\|r\|/|\lambda|$
+.  `EPS_CONV_NORM` - convergence criterion relative to matrix norms, $\|r\|/(\|A\|+|\lambda|\|B\|)$
+-  `EPS_CONV_USER` - convergence dictated by user-provided function
 
-.seealso: EPSSetConvergenceTest(), EPSSetConvergenceTestFunction()
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSSetConvergenceTest()`, `EPSSetConvergenceTestFunction()`
 E*/
 typedef enum { EPS_CONV_ABS,
                EPS_CONV_REL,
@@ -157,23 +424,78 @@ typedef enum { EPS_CONV_ABS,
                EPS_CONV_USER } EPSConv;
 
 /*E
-    EPSStop - Determines the stopping test
+   EPSStop - The stopping test to decide the termination of the outer loop
+   of the eigensolver.
 
-    Level: advanced
+   Values:
++  `EPS_STOP_BASIC`     - default stopping test
+.  `EPS_STOP_USER`      - user-provided stopping test
+-  `EPS_STOP_THRESHOLD` - threshold stopping test
 
-.seealso: EPSSetStoppingTest(), EPSSetStoppingTestFunction()
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSSetStoppingTest()`, `EPSSetStoppingTestFunction()`
 E*/
 typedef enum { EPS_STOP_BASIC,
                EPS_STOP_USER,
                EPS_STOP_THRESHOLD } EPSStop;
 
+/*MC
+   EPS_STOP_BASIC - The default stopping test.
+
+   Note:
+   By default, the termination of the outer loop is decided by calling
+   `EPSStoppingBasic()`, which will stop if all requested eigenvalues are converged,
+   or if the maximum number of iterations has been reached.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSStop`, `EPSSetStoppingTest()`, `EPSStoppingBasic()`
+M*/
+
+/*MC
+   EPS_STOP_USER - The user-provided stopping test.
+
+   Note:
+   Customized stopping test using the user-provided function given with
+   `EPSSetStoppingTestFunction()`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSStop`, `EPSSetStoppingTest()`, `EPSSetStoppingTestFunction()`
+M*/
+
+/*MC
+   EPS_STOP_THRESHOLD - The threshold stopping test.
+
+   Note:
+   When a threshold has been provided with `EPSSetThreshold()`, the termination
+   of the outer loop is decided by calling `EPSStoppingThreshold()`, which will
+   stop when one of the computed eigenvalues is not above/below the threshold.
+   If a number of wanted eigenvalues has been specified via `EPSSetDimensions()`
+   then it is also taken into account, and the solver will stop when one of the
+   two conditions (threshold or number of converged values) is met.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSStop`, `EPSSetStoppingTest()`, `EPSStoppingThreshold()`, `EPSSetThreshold()`, `EPSSetDimensions()`
+M*/
+
 /*E
-    EPSConvergedReason - Reason an eigensolver was said to
-         have converged or diverged
+   EPSConvergedReason - Reason an eigensolver was determined to have converged
+   or diverged.
 
-    Level: intermediate
+   Values:
++  `EPS_CONVERGED_TOL`          - converged up to tolerance
+.  `EPS_CONVERGED_USER`         - converged due to a user-defined condition
+.  `EPS_DIVERGED_ITS`           - exceeded the maximum number of allowed iterations
+.  `EPS_DIVERGED_BREAKDOWN`     - generic breakdown in method
+.  `EPS_DIVERGED_SYMMETRY_LOST` - pseudo-Lanczos was not able to keep symmetry
+-  `EPS_CONVERGED_ITERATING`    - the solver is still running
 
-.seealso: EPSSolve(), EPSGetConvergedReason(), EPSSetTolerances()
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSSolve()`, `EPSGetConvergedReason()`, `EPSSetTolerances()`
 E*/
 typedef enum {/* converged */
               EPS_CONVERGED_TOL                =  1,
@@ -185,13 +507,71 @@ typedef enum {/* converged */
               EPS_CONVERGED_ITERATING          =  0} EPSConvergedReason;
 SLEPC_EXTERN const char *const*EPSConvergedReasons;
 
+/*MC
+   EPS_CONVERGED_TOL - The computed error estimates, based on residual norms,
+   for all requested eigenvalues are below the tolerance.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSSolve()`, `EPSGetConvergedReason()`, `EPSConvergedReason`
+M*/
+
+/*MC
+   EPS_CONVERGED_USER - The solver was declared converged due to a user-defined condition.
+
+   Note:
+   This happens only when a user-defined stopping test has been set with
+   `EPSSetStoppingTestFunction()`.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSSolve()`, `EPSGetConvergedReason()`, `EPSConvergedReason`, `EPSSetStoppingTestFunction()`
+M*/
+
+/*MC
+   EPS_DIVERGED_ITS - Exceeded the maximum number of allowed iterations
+   before the convergence criterion was satisfied.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSSolve()`, `EPSGetConvergedReason()`, `EPSConvergedReason`
+M*/
+
+/*MC
+   EPS_DIVERGED_BREAKDOWN - A breakdown in the solver was detected so the
+   method could not continue.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSSolve()`, `EPSGetConvergedReason()`, `EPSConvergedReason`
+M*/
+
+/*MC
+   EPS_DIVERGED_SYMMETRY_LOST - The selected solver uses a pseudo-Lanczos recurrence,
+   which is numerically unstable, and a symmetry test revealed that instability
+   had appeared so the solver could not continue.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSSolve()`, `EPSGetConvergedReason()`, `EPSConvergedReason`
+M*/
+
+/*MC
+   EPS_CONVERGED_ITERATING - This value is returned if `EPSGetConvergedReason()` is called
+   while `EPSSolve()` is still running.
+
+   Level: intermediate
+
+.seealso: [](ch:eps), `EPSSolve()`, `EPSGetConvergedReason()`, `EPSConvergedReason`
+M*/
+
 /*S
    EPSStoppingCtx - Data structure (C struct) to hold additional information to
    be used in some stopping test functions.
 
    Level: advanced
 
-.seealso: EPSSetStoppingTestFunction()
+.seealso: [](ch:eps), `EPSSetStoppingTestFunction()`
 S*/
 struct _n_EPSStoppingCtx {
   PetscReal firstev;    /* the (absolute) value of the first converged eigenvalue */
@@ -288,74 +668,76 @@ SLEPC_EXTERN PetscErrorCode EPSSetInitialSpace(EPS,PetscInt,Vec[]);
 SLEPC_EXTERN PetscErrorCode EPSSetLeftInitialSpace(EPS,PetscInt,Vec[]);
 
 /*S
-  EPSMonitorFn - A function prototype for functions provided to EPSMonitorSet()
+   EPSMonitorFn - A function prototype for functions provided to `EPSMonitorSet()`.
 
-  Calling Sequence:
-+   eps    - eigensolver context obtained from EPSCreate()
-.   its    - iteration number
-.   nconv  - number of converged eigenpairs
-.   eigr   - real part of the eigenvalues
-.   eigi   - imaginary part of the eigenvalues
-.   errest - relative error estimates for each eigenpair
-.   nest   - number of error estimates
--   ctx    - optional monitoring context, as provided with EPSMonitorSet()
+   Calling Sequence:
++  eps    - the linear eigensolver context
+.  its    - iteration number
+.  nconv  - number of converged eigenpairs
+.  eigr   - real part of the eigenvalues
+.  eigi   - imaginary part of the eigenvalues
+.  errest - relative error estimates for each eigenpair
+.  nest   - number of error estimates
+-  ctx    - optional monitoring context, as provided with `EPSMonitorSet()`
 
-  Level: beginner
+   Level: intermediate
 
-.seealso: EPSMonitorSet()
+.seealso: [](ch:eps), `EPSMonitorSet()`
 S*/
-PETSC_EXTERN_TYPEDEF typedef PetscErrorCode EPSMonitorFn(EPS eps,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,void *ctx);
+PETSC_EXTERN_TYPEDEF typedef PetscErrorCode EPSMonitorFn(EPS eps,PetscInt its,PetscInt nconv,PetscScalar eigr[],PetscScalar eigi[],PetscReal errest[],PetscInt nest,void *ctx);
 
 /*S
-  EPSMonitorRegisterFn - A function prototype for functions provided to EPSMonitorRegister()
+   EPSMonitorRegisterFn - A function prototype for functions provided to `EPSMonitorRegister()`.
 
-  Calling Sequence:
-+   eps    - eigensolver context obtained from EPSCreate()
-.   its    - iteration number
-.   nconv  - number of converged eigenpairs
-.   eigr   - real part of the eigenvalues
-.   eigi   - imaginary part of the eigenvalues
-.   errest - relative error estimates for each eigenpair
-.   nest   - number of error estimates
--   ctx    - PetscViewerAndFormat object
+   Calling Sequence:
++  eps    - the linear eigensolver context
+.  its    - iteration number
+.  nconv  - number of converged eigenpairs
+.  eigr   - real part of the eigenvalues
+.  eigi   - imaginary part of the eigenvalues
+.  errest - relative error estimates for each eigenpair
+.  nest   - number of error estimates
+-  ctx    - `PetscViewerAndFormat` object
 
-  Level: beginner
+   Level: advanced
 
-  Note:
-  This is an EPSMonitorFn specialized for a context of PetscViewerAndFormat.
+   Note:
+   This is an `EPSMonitorFn` specialized for a context of `PetscViewerAndFormat`.
 
-.seealso: EPSMonitorSet(), EPSMonitorRegister(), EPSMonitorFn, EPSMonitorRegisterCreateFn, EPSMonitorRegisterDestroyFn
+.seealso: [](ch:eps), `EPSMonitorSet()`, `EPSMonitorRegister()`, `EPSMonitorFn`, `EPSMonitorRegisterCreateFn`, `EPSMonitorRegisterDestroyFn`
 S*/
-PETSC_EXTERN_TYPEDEF typedef PetscErrorCode EPSMonitorRegisterFn(EPS eps,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *ctx);
+PETSC_EXTERN_TYPEDEF typedef PetscErrorCode EPSMonitorRegisterFn(EPS eps,PetscInt its,PetscInt nconv,PetscScalar eigr[],PetscScalar eigi[],PetscReal errest[],PetscInt nest,PetscViewerAndFormat *ctx);
 
 /*S
-  EPSMonitorRegisterCreateFn - A function prototype for functions that do the creation when provided to EPSMonitorRegister()
+   EPSMonitorRegisterCreateFn - A function prototype for functions that do the
+   creation when provided to `EPSMonitorRegister()`.
 
-  Calling Sequence:
-+   viewer - the viewer to be used with the EPSMonitorRegisterFn
-.   format - the format of the viewer
-.   ctx    - a context for the monitor
--   result - a PetscViewerAndFormat object
+   Calling Sequence:
++  viewer - the viewer to be used with the `EPSMonitorRegisterFn`
+.  format - the format of the viewer
+.  ctx    - a context for the monitor
+-  result - a `PetscViewerAndFormat` object
 
-  Level: beginner
+   Level: advanced
 
-.seealso: EPSMonitorRegisterFn, EPSMonitorSet(), EPSMonitorRegister(), EPSMonitorFn, EPSMonitorRegisterDestroyFn
+.seealso: [](ch:eps), `EPSMonitorRegisterFn`, `EPSMonitorSet()`, `EPSMonitorRegister()`, `EPSMonitorFn`, `EPSMonitorRegisterDestroyFn`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode EPSMonitorRegisterCreateFn(PetscViewer viewer,PetscViewerFormat format,void *ctx,PetscViewerAndFormat **result);
 
 /*S
-  EPSMonitorRegisterDestroyFn - A function prototype for functions that do the after use destruction when provided to EPSMonitorRegister()
+   EPSMonitorRegisterDestroyFn - A function prototype for functions that do the after
+   use destruction when provided to `EPSMonitorRegister()`.
 
-  Calling Sequence:
-.   vf - a PetscViewerAndFormat object to be destroyed, including any context
+   Calling Sequence:
+.  vf - a `PetscViewerAndFormat` object to be destroyed, including any context
 
-  Level: beginner
+   Level: advanced
 
-.seealso: EPSMonitorRegisterFn, EPSMonitorSet(), EPSMonitorRegister(), EPSMonitorFn, EPSMonitorRegisterCreateFn
+.seealso: [](ch:eps), `EPSMonitorRegisterFn`, `EPSMonitorSet()`, `EPSMonitorRegister()`, `EPSMonitorFn`, `EPSMonitorRegisterCreateFn`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode EPSMonitorRegisterDestroyFn(PetscViewerAndFormat **result);
 
-SLEPC_EXTERN PetscErrorCode EPSMonitor(EPS,PetscInt,PetscInt,PetscScalar*,PetscScalar*,PetscReal*,PetscInt);
+SLEPC_EXTERN PetscErrorCode EPSMonitor(EPS,PetscInt,PetscInt,PetscScalar[],PetscScalar[],PetscReal[],PetscInt);
 SLEPC_EXTERN PetscErrorCode EPSMonitorSet(EPS,EPSMonitorFn,void*,PetscCtxDestroyFn*);
 SLEPC_EXTERN PetscErrorCode EPSMonitorCancel(EPS);
 SLEPC_EXTERN PetscErrorCode EPSGetMonitorContext(EPS,void*);
@@ -373,8 +755,8 @@ SLEPC_EXTERN EPSMonitorRegisterFn        EPSMonitorConvergedDrawLG;
 SLEPC_EXTERN EPSMonitorRegisterCreateFn  EPSMonitorConvergedDrawLGCreate;
 SLEPC_EXTERN EPSMonitorRegisterDestroyFn EPSMonitorConvergedDestroy;
 
-SLEPC_EXTERN PetscErrorCode EPSSetOptionsPrefix(EPS,const char*);
-SLEPC_EXTERN PetscErrorCode EPSAppendOptionsPrefix(EPS,const char*);
+SLEPC_EXTERN PetscErrorCode EPSSetOptionsPrefix(EPS,const char[]);
+SLEPC_EXTERN PetscErrorCode EPSAppendOptionsPrefix(EPS,const char[]);
 SLEPC_EXTERN PetscErrorCode EPSGetOptionsPrefix(EPS,const char*[]);
 
 SLEPC_EXTERN PetscFunctionList EPSList;
@@ -389,20 +771,20 @@ SLEPC_EXTERN PetscErrorCode EPSAllocateSolution(EPS,PetscInt);
 SLEPC_EXTERN PetscErrorCode EPSReallocateSolution(EPS,PetscInt);
 
 /*S
-  EPSConvergenceTestFn - A prototype of an EPS convergence test function that would be passed to EPSSetConvergenceTestFunction()
+   EPSConvergenceTestFn - A prototype of an `EPS` convergence test function that
+   would be passed to `EPSSetConvergenceTestFunction()`.
 
-  Calling Sequence:
-+   eps    - eigensolver context obtained from EPSCreate()
-.   eigr   - real part of the eigenvalue
-.   eigi   - imaginary part of the eigenvalue
-.   res    - residual norm associated to the eigenpair
-.   errest - [output] computed error estimate
--   ctx    - [optional] user-defined context for private data for the
-             convergence test routine (may be NULL)
+   Calling Sequence:
++  eps    - the linear eigensolver context
+.  eigr   - real part of the eigenvalue
+.  eigi   - imaginary part of the eigenvalue
+.  res    - residual norm associated to the eigenpair
+.  errest - [output] computed error estimate
+-  ctx    - optional convergence context, as set by `EPSSetConvergenceTestFunction()`
 
-  Level: advanced
+   Level: advanced
 
-.seealso: EPSSetConvergenceTestFunction()
+.seealso: [](ch:eps), `EPSSetConvergenceTest()`, `EPSSetConvergenceTestFunction()`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode EPSConvergenceTestFn(EPS eps,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx);
 
@@ -414,21 +796,27 @@ SLEPC_EXTERN EPSConvergenceTestFn EPSConvergedNorm;
 SLEPC_EXTERN PetscErrorCode EPSSetConvergenceTestFunction(EPS,EPSConvergenceTestFn*,void*,PetscCtxDestroyFn*);
 
 /*S
-  EPSStoppingTestFn - A prototype of an EPS stopping test function that would be passed to EPSSetStoppingTestFunction()
+   EPSStoppingTestFn - A prototype of an `EPS` stopping test function that would
+   be passed to `EPSSetStoppingTestFunction()`.
 
-  Calling Sequence:
-+   eps    - eigensolver context obtained from EPSCreate()
-.   its    - current number of iterations
-.   max_it - maximum number of iterations
-.   nconv  - number of currently converged eigenpairs
-.   nev    - number of requested eigenpairs
-.   reason - [output] result of the stopping test
--   ctx    - [optional] user-defined context for private data for the
-             stopping test routine (may be NULL)
+   Calling Sequence:
++  eps    - the linear eigensolver context
+.  its    - current number of iterations
+.  max_it - maximum number of iterations
+.  nconv  - number of currently converged eigenpairs
+.  nev    - number of requested eigenpairs
+.  reason - [output] result of the stopping test
+-  ctx    - optional stopping context, as set by `EPSSetStoppingTestFunction()`
 
-  Level: advanced
+   Note:
+   A positive value of `reason` indicates that the iteration has finished successfully
+   (converged), and a negative value indicates an error condition (diverged). If
+   the iteration needs to be continued, `reason` must be set to `EPS_CONVERGED_ITERATING`
+   (zero).
 
-.seealso: EPSSetStoppingTestFunction()
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSSetStoppingTest()`, `EPSSetStoppingTestFunction()`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode EPSStoppingTestFn(EPS eps,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,EPSConvergedReason *reason,void *ctx);
 
@@ -444,17 +832,82 @@ SLEPC_EXTERN PetscErrorCode EPSSetArbitrarySelection(EPS,SlepcArbitrarySelection
 /* --------- options specific to particular eigensolvers -------- */
 
 /*E
-    EPSPowerShiftType - determines the type of shift used in the Power iteration
+   EPSPowerShiftType - The type of shift used in the Power iteration solver.
 
-    Level: advanced
+   Values:
++  `EPS_POWER_SHIFT_CONSTANT`  - constant shift
+.  `EPS_POWER_SHIFT_RAYLEIGH`  - variable shift using Rayleigh quotient
+-  `EPS_POWER_SHIFT_WILKINSON` - variable shift using Wilkinson's approach
 
-.seealso: EPSPowerSetShiftType(), EPSPowerGetShiftType()
+   Note:
+   Details of the three variants can be found in {cite:p}`Her05`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSPowerSetShiftType()`, `EPSPowerGetShiftType()`
 E*/
 typedef enum { EPS_POWER_SHIFT_CONSTANT,
                EPS_POWER_SHIFT_RAYLEIGH,
                EPS_POWER_SHIFT_WILKINSON } EPSPowerShiftType;
 SLEPC_EXTERN const char *EPSPowerShiftTypes[];
 
+/*MC
+   EPS_POWER_SHIFT_CONSTANT - The power iteration will use a constant shift.
+
+   Note:
+   Together with `STSINVERT`, the `EPSPOWER` solver implements the inverse iteration
+   method, i.e., it will apply $(A-\sigma I)^{-1}$ at each iteration, by solving
+   a linear system. By default, the shift $\sigma$ is constant and given by the
+   user with `EPSSetTarget()`.
+
+   Details of the three variants can be found in {cite:p}`Her05`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSPowerShiftType`, `EPSPowerSetShiftType()`, `STSetShift()`, `EPSSetTarget()`, `EPS_POWER_SHIFT_RAYLEIGH`, `EPS_POWER_SHIFT_WILKINSON`
+M*/
+
+/*MC
+   EPS_POWER_SHIFT_RAYLEIGH - The power iteration will use a variable shift
+   computed with the Rayleigh quotient.
+
+   Notes:
+   Together with `STSINVERT`, the `EPSPOWER` solver implements the inverse iteration
+   method, i.e., it will apply $(A-\sigma I)^{-1}$ at each iteration, by solving
+   a linear system. With this strategy, the value of the shift will be updated at
+   each iteration as $\sigma=\frac{x^*Ax}{x^*x}$, where $x$ is the current eigenvector
+   approximation. The resulting iteration is the RQI method.
+
+   Updating the shift may involve a high computational cost if the linear solve
+   is done via a factorization.
+
+   Details of the three variants can be found in {cite:p}`Her05`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSPowerShiftType`, `EPSPowerSetShiftType()`, `STSetShift()`, `EPSSetTarget()`, `EPS_POWER_SHIFT_CONSTANT`, `EPS_POWER_SHIFT_WILKINSON`
+M*/
+
+/*MC
+   EPS_POWER_SHIFT_WILKINSON - The power iteration will use a variable shift
+   computed with Wilkinson's approach.
+
+   Note:
+   Together with `STSINVERT`, the `EPSPOWER` solver implements the inverse iteration
+   method, i.e., it will apply $(A-\sigma I)^{-1}$ at each iteration, by solving
+   a linear system. With this strategy, the value of the shift will be updated at
+   each iteration as proposed by Wilkinson, see {cite:p}`Par80{8.10}`.
+
+   Updating the shift may involve a high computational cost if the linear solve
+   is done via a factorization.
+
+   Details of the three variants can be found in {cite:p}`Her05`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSPowerShiftType`, `EPSPowerSetShiftType()`, `STSetShift()`, `EPSSetTarget()`, `EPS_POWER_SHIFT_CONSTANT`, `EPS_POWER_SHIFT_RAYLEIGH`
+M*/
+
 SLEPC_EXTERN PetscErrorCode EPSPowerSetShiftType(EPS,EPSPowerShiftType);
 SLEPC_EXTERN PetscErrorCode EPSPowerGetShiftType(EPS,EPSPowerShiftType*);
 SLEPC_EXTERN PetscErrorCode EPSPowerSetNonlinear(EPS,PetscBool);
@@ -470,12 +923,21 @@ SLEPC_EXTERN PetscErrorCode EPSArnoldiSetDelayed(EPS,PetscBool);
 SLEPC_EXTERN PetscErrorCode EPSArnoldiGetDelayed(EPS,PetscBool*);
 
 /*E
-    EPSKrylovSchurBSEType - the method to be used in the Krylov-Schur solver
-    for the case of BSE structured eigenproblems
+   EPSKrylovSchurBSEType - The method to be used in the Krylov-Schur solver
+   for the case of BSE structured eigenproblems.
 
-    Level: advanced
+   Values:
++  `EPS_KRYLOVSCHUR_BSE_SHAO`         - a Lanczos method proposed by Shao and coauthors
+.  `EPS_KRYLOVSCHUR_BSE_GRUNING`      - a Lanczos method proposed by Gruning and coauthors
+-  `EPS_KRYLOVSCHUR_BSE_PROJECTEDBSE` - a Lanczos method resulting is a projected problem with BSE structure
 
-.seealso: EPSKrylovSchurSetBSEType(), EPSKrylovSchurGetBSEType()
+   Note:
+   All variants are implemented in combination with a thick restart, see
+   the details in {cite:p}`Alv25`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSKrylovSchurSetBSEType()`, `EPSKrylovSchurGetBSEType()`
 E*/
 typedef enum { EPS_KRYLOVSCHUR_BSE_SHAO,
                EPS_KRYLOVSCHUR_BSE_GRUNING,
@@ -494,7 +956,7 @@ SLEPC_EXTERN PetscErrorCode EPSKrylovSchurSetDetectZeros(EPS,PetscBool);
 SLEPC_EXTERN PetscErrorCode EPSKrylovSchurGetDetectZeros(EPS,PetscBool*);
 SLEPC_EXTERN PetscErrorCode EPSKrylovSchurSetDimensions(EPS,PetscInt,PetscInt,PetscInt);
 SLEPC_EXTERN PetscErrorCode EPSKrylovSchurGetDimensions(EPS,PetscInt*,PetscInt*,PetscInt*);
-SLEPC_EXTERN PetscErrorCode EPSKrylovSchurSetSubintervals(EPS,PetscReal*);
+SLEPC_EXTERN PetscErrorCode EPSKrylovSchurSetSubintervals(EPS,PetscReal[]);
 SLEPC_EXTERN PetscErrorCode EPSKrylovSchurGetSubintervals(EPS,PetscReal*[]);
 SLEPC_EXTERN PetscErrorCode EPSKrylovSchurGetInertias(EPS,PetscInt*,PetscReal*[],PetscInt*[]);
 SLEPC_EXTERN PetscErrorCode EPSKrylovSchurGetSubcommInfo(EPS,PetscInt*,PetscInt*,Vec*);
@@ -504,12 +966,23 @@ SLEPC_EXTERN PetscErrorCode EPSKrylovSchurUpdateSubcommMats(EPS,PetscScalar,Pets
 SLEPC_EXTERN PetscErrorCode EPSKrylovSchurGetKSP(EPS,KSP*);
 
 /*E
-    EPSLanczosReorthogType - determines the type of reorthogonalization
-    used in the Lanczos method
+   EPSLanczosReorthogType - The type of reorthogonalization used in `EPSLANCZOS`.
 
-    Level: advanced
+   Values:
++  `EPS_LANCZOS_REORTHOG_LOCAL`     - local orthogonalization, only involves previous two vectors
+.  `EPS_LANCZOS_REORTHOG_FULL`      - full orthogonalization against all previous vectors
+.  `EPS_LANCZOS_REORTHOG_SELECTIVE` - selective reorthogonalization against nearly converged Ritz vectors
+.  `EPS_LANCZOS_REORTHOG_PERIODIC`  - periodic reorthogonalization against all previous vectors
+.  `EPS_LANCZOS_REORTHOG_PARTIAL`   - partial reorthogonalization against as subset of previous vectors
+-  `EPS_LANCZOS_REORTHOG_DELAYED`   - full orthogonalization with delayed reorthogonalization
 
-.seealso: EPSLanczosSetReorthog(), EPSLanczosGetReorthog()
+   Note:
+   Details of the different reorthogonalization strategies can be found in
+   {cite:p}`Her06`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSLanczosSetReorthog()`, `EPSLanczosGetReorthog()`
 E*/
 typedef enum { EPS_LANCZOS_REORTHOG_LOCAL,
                EPS_LANCZOS_REORTHOG_FULL,
@@ -523,11 +996,14 @@ SLEPC_EXTERN PetscErrorCode EPSLanczosSetReorthog(EPS,EPSLanczosReorthogType);
 SLEPC_EXTERN PetscErrorCode EPSLanczosGetReorthog(EPS,EPSLanczosReorthogType*);
 
 /*E
-    EPSPRIMMEMethod - determines the method selected in the PRIMME library
+   EPSPRIMMEMethod - The method selected in the PRIMME library.
 
-    Level: advanced
+   Note:
+   See the documentation of PRIMME {cite:p}`Sta10` for a description of the methods.
 
-.seealso: EPSPRIMMESetMethod(), EPSPRIMMEGetMethod()
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSPRIMMESetMethod()`, `EPSPRIMMEGetMethod()`
 E*/
 typedef enum { EPS_PRIMME_DYNAMIC             = 1,
                EPS_PRIMME_DEFAULT_MIN_TIME    = 2,
@@ -590,22 +1066,36 @@ SLEPC_EXTERN PetscErrorCode EPSLOBPCGSetLocking(EPS,PetscBool);
 SLEPC_EXTERN PetscErrorCode EPSLOBPCGGetLocking(EPS,PetscBool*);
 
 /*E
-    EPSCISSQuadRule - determines the quadrature rule in the CISS solver
+   EPSCISSQuadRule - The quadrature rule used in the `EPSCISS` solver.
 
-    Level: advanced
+   Values:
++  `EPS_CISS_QUADRULE_TRAPEZOIDAL` - trapezoidal rule
+-  `EPS_CISS_QUADRULE_CHEBYSHEV`   - Gauss quadrature on Chebyshev points
 
-.seealso: EPSCISSSetQuadRule(), EPSCISSGetQuadRule()
+   Note:
+   For a detailed description see {cite:p}`Mae16`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSCISSSetQuadRule()`, `EPSCISSGetQuadRule()`
 E*/
 typedef enum { EPS_CISS_QUADRULE_TRAPEZOIDAL = 1,
                EPS_CISS_QUADRULE_CHEBYSHEV   = 2 } EPSCISSQuadRule;
 SLEPC_EXTERN const char *EPSCISSQuadRules[];
 
 /*E
-    EPSCISSExtraction - determines the extraction technique in the CISS solver
+   EPSCISSExtraction - The extraction technique used in the `EPSCISS` solver.
 
-    Level: advanced
+   Values:
++  `EPS_CISS_EXTRACTION_RITZ`   - Ritz approximations from Rayleigh-Ritz projection
+-  `EPS_CISS_EXTRACTION_HANKEL` - use Hankel pencil as in the original Sakurai-Sugiura method
 
-.seealso: EPSCISSSetExtraction(), EPSCISSGetExtraction()
+   Note:
+   For a detailed description see {cite:p}`Mae16`.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSCISSSetExtraction()`, `EPSCISSGetExtraction()`
 E*/
 typedef enum { EPS_CISS_EXTRACTION_RITZ,
                EPS_CISS_EXTRACTION_HANKEL } EPSCISSExtraction;
@@ -634,22 +1124,38 @@ SLEPC_EXTERN PetscErrorCode EPSBLOPEXSetBlockSize(EPS,PetscInt);
 SLEPC_EXTERN PetscErrorCode EPSBLOPEXGetBlockSize(EPS,PetscInt*);
 
 /*E
-    EPSEVSLDOSMethod - the method to approximate the density of states (DOS) in the EVSL solver
+   EPSEVSLDOSMethod - The method to approximate the density of states (DOS)
+   in the `EPSEVSL` solver.
 
-    Level: advanced
+   Values:
++  `EPS_EVSL_DOS_KPM`     - Kernel Polynomial Method
+-  `EPS_EVSL_DOS_LANCZOS` - Lanczos method
 
-.seealso: EPSEVSLSetDOSParameters(), EPSEVSLGetDOSParameters()
+   Note:
+   See the documentation of EVSL {cite:p}`Li19` for an explanation.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSEVSLSetDOSParameters()`, `EPSEVSLGetDOSParameters()`
 E*/
 typedef enum { EPS_EVSL_DOS_KPM,
                EPS_EVSL_DOS_LANCZOS } EPSEVSLDOSMethod;
 SLEPC_EXTERN const char *EPSEVSLDOSMethods[];
 
 /*E
-    EPSEVSLDamping - the damping type used in the EVSL solver
+   EPSEVSLDamping - The damping type used in the `EPSEVSL` solver.
 
-    Level: advanced
+   Values:
++  `EPS_EVSL_DAMPING_NONE`    - no damping
+.  `EPS_EVSL_DAMPING_JACKSON` - Jackson damping
+-  `EPS_EVSL_DAMPING_SIGMA`   - Lanczos damping
 
-.seealso: EPSEVSLSetDOSParameters(), EPSEVSLGetDOSParameters()
+   Note:
+   See the documentation of EVSL {cite:p}`Li19` for an explanation.
+
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSEVSLSetDOSParameters()`, `EPSEVSLGetDOSParameters()`
 E*/
 typedef enum { EPS_EVSL_DAMPING_NONE,
                EPS_EVSL_DAMPING_JACKSON,
