@@ -23,50 +23,75 @@ SLEPC_EXTERN PetscErrorCode NEPInitializePackage(void);
 SLEPC_EXTERN PetscErrorCode NEPFinalizePackage(void);
 
 /*S
-     NEP - Abstract SLEPc object that manages all solvers for
-     nonlinear eigenvalue problems.
+   NEP - SLEPc object that manages all solvers for nonlinear eigenvalue problems.
 
    Level: beginner
 
-.seealso:  NEPCreate()
+.seealso: [](ch:nep), `NEPCreate()`
 S*/
 typedef struct _p_NEP* NEP;
 
 /*J
-    NEPType - String with the name of a nonlinear eigensolver
+   NEPType - String with the name of a nonlinear eigensolver.
 
    Level: beginner
 
-.seealso: NEPSetType(), NEP
+.seealso: [](ch:nep), `NEPSetType()`, `NEP`
 J*/
 typedef const char *NEPType;
 #define NEPRII       "rii"
 #define NEPSLP       "slp"
 #define NEPNARNOLDI  "narnoldi"
+#define NEPNLEIGS    "nleigs"
 #define NEPCISS      "ciss"
 #define NEPINTERPOL  "interpol"
-#define NEPNLEIGS    "nleigs"
 
 /* Logging support */
 SLEPC_EXTERN PetscClassId NEP_CLASSID;
 
 /*E
-    NEPProblemType - Determines the type of the nonlinear eigenproblem
+   NEPProblemType - Determines the type of the nonlinear eigenproblem.
 
-    Level: intermediate
+   Values:
++  `NEP_GENERAL`  - no particular structure
+-  `NEP_RATIONAL` - problem defined in split form with all $f_i$ rational
 
-.seealso: NEPSetProblemType(), NEPGetProblemType()
+   Note:
+   Currently, the `NEP_RATIONAL` case is only used in `NEPNLEIGS` to
+   determine the singularities automatically.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSetProblemType()`, `NEPGetProblemType()`
 E*/
 typedef enum { NEP_GENERAL  = 1,
-               NEP_RATIONAL = 2     /* NEP defined in split form with all f_i rational */
+               NEP_RATIONAL = 2
              } NEPProblemType;
 
 /*E
-    NEPWhich - Determines which part of the spectrum is requested
+   NEPWhich - Determines which part of the spectrum is requested.
 
-    Level: intermediate
+   Values:
++  `NEP_LARGEST_MAGNITUDE`  - largest $|\lambda|$
+.  `NEP_SMALLEST_MAGNITUDE` - smallest $|\lambda|$
+.  `NEP_LARGEST_REAL`       - largest $\mathrm{Re}(\lambda)$
+.  `NEP_SMALLEST_REAL`      - smallest $\mathrm{Re}(\lambda)$
+.  `NEP_LARGEST_IMAGINARY`  - largest $\mathrm{Im}(\lambda)$
+.  `NEP_SMALLEST_IMAGINARY` - smallest $\mathrm{Im}(\lambda)$
+.  `NEP_TARGET_MAGNITUDE`   - smallest $|\lambda-\tau|$
+.  `NEP_TARGET_REAL`        - smallest $|\mathrm{Re}(\lambda-\tau)|$
+.  `NEP_TARGET_IMAGINARY`   - smallest $|\mathrm{Im}(\lambda-\tau)|$
+.  `NEP_ALL`                - all $\lambda\in\Omega$
+-  `NEP_WHICH_USER`         - user-defined sorting criterion
 
-.seealso: NEPSetWhichEigenpairs(), NEPGetWhichEigenpairs()
+   Notes:
+   The target $\tau$ is a scalar value provided with `NEPSetTarget()`.
+
+   The case `NEP_ALL` needs a region $\Omega$ specified with an `RG` object.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSetWhichEigenpairs()`, `NEPSetTarget()`
 E*/
 typedef enum { NEP_LARGEST_MAGNITUDE  = 1,
                NEP_SMALLEST_MAGNITUDE = 2,
@@ -81,11 +106,16 @@ typedef enum { NEP_LARGEST_MAGNITUDE  = 1,
                NEP_WHICH_USER         = 11 } NEPWhich;
 
 /*E
-    NEPErrorType - The error type used to assess accuracy of computed solutions
+   NEPErrorType - The error type used to assess the accuracy of computed solutions.
 
-    Level: intermediate
+   Values:
++  `NEP_ERROR_ABSOLUTE` - compute error bound as $\|r\|$
+.  `NEP_ERROR_RELATIVE` - compute error bound as $\|r\|/|\lambda|$
+-  `NEP_ERROR_BACKWARD` - compute error bound as $\|r\|/(\sum_i|f_i(\lambda)|\|A_i\|)$
 
-.seealso: NEPComputeError()
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPComputeError()`
 E*/
 typedef enum { NEP_ERROR_ABSOLUTE,
                NEP_ERROR_RELATIVE,
@@ -93,11 +123,19 @@ typedef enum { NEP_ERROR_ABSOLUTE,
 SLEPC_EXTERN const char *NEPErrorTypes[];
 
 /*E
-    NEPRefine - The refinement type
+   NEPRefine - The type of Newton iterative refinement.
 
-    Level: intermediate
+   Values:
++  `NEP_REFINE_NONE`     - no refinement
+.  `NEP_REFINE_SIMPLE`   - refinement of each converged eigenpair individually
+-  `NEP_REFINE_MULTIPLE` - refinement of the invariant pair as a whole
 
-.seealso: NEPSetRefine()
+   Note:
+   See section [](#sec:refine) for a discussion of the different refinement strategies.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), [](#sec:refine), `NEPSetRefine()`
 E*/
 typedef enum { NEP_REFINE_NONE,
                NEP_REFINE_SIMPLE,
@@ -105,11 +143,22 @@ typedef enum { NEP_REFINE_NONE,
 SLEPC_EXTERN const char *NEPRefineTypes[];
 
 /*E
-    NEPRefineScheme - The scheme used for solving linear systems during iterative refinement
+   NEPRefineScheme - The scheme used for solving linear systems during iterative refinement.
 
-    Level: intermediate
+   Values:
++  `NEP_REFINE_SCHEME_SCHUR`    - use the Schur complement
+.  `NEP_REFINE_SCHEME_MBE`      - use the mixed block elimination (MBE) scheme
+-  `NEP_REFINE_SCHEME_EXPLICIT` - build the full matrix explicitly
 
-.seealso: NEPSetRefine()
+   Note:
+   Iterative refinement may be very costly, due to the expensive linear
+   solves. These linear systems have a particular structure that can be
+   exploited in different ways, as described in {cite:p}`Cam16b`. See
+   `NEPSetRefine()` for additional details.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), [](#sec:refine), `NEPSetRefine()`
 E*/
 typedef enum { NEP_REFINE_SCHEME_SCHUR    = 1,
                NEP_REFINE_SCHEME_MBE      = 2,
@@ -117,11 +166,17 @@ typedef enum { NEP_REFINE_SCHEME_SCHUR    = 1,
 SLEPC_EXTERN const char *NEPRefineSchemes[];
 
 /*E
-    NEPConv - Determines the convergence test
+   NEPConv - The convergence criterion to be used by the solver.
 
-    Level: intermediate
+   Values:
++  `NEP_CONV_ABS`  - absolute convergence criterion, $\|r\|$
+.  `NEP_CONV_REL`  - convergence criterion relative to eigenvalue, $\|r\|/|\lambda|$
+.  `NEP_CONV_NORM` - convergence criterion relative to matrix norms, $\|r\|/(\sum_j|f_j(\lambda)|\|A_j\|)$
+-  `NEP_CONV_USER` - convergence dictated by user-provided function
 
-.seealso: NEPSetConvergenceTest(), NEPSetConvergenceTestFunction()
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSetConvergenceTest()`, `NEPSetConvergenceTestFunction()`
 E*/
 typedef enum { NEP_CONV_ABS,
                NEP_CONV_REL,
@@ -129,22 +184,61 @@ typedef enum { NEP_CONV_ABS,
                NEP_CONV_USER } NEPConv;
 
 /*E
-    NEPStop - Determines the stopping test
+   NEPStop - The stopping test to decide the termination of the outer loop
+   of the eigensolver.
 
-    Level: advanced
+   Values:
++  `NEP_STOP_BASIC` - default stopping test
+-  `NEP_STOP_USER`  - user-provided stopping test
 
-.seealso: NEPSetStoppingTest(), NEPSetStoppingTestFunction()
+   Level: advanced
+
+.seealso: [](ch:nep), `NEPSetStoppingTest()`, `NEPSetStoppingTestFunction()`
 E*/
 typedef enum { NEP_STOP_BASIC,
                NEP_STOP_USER } NEPStop;
 
+/*MC
+   NEP_STOP_BASIC - The default stopping test.
+
+   Note:
+   By default, the termination of the outer loop is decided by calling
+   `NEPStoppingBasic()`, which will stop if all requested eigenvalues are converged,
+   or if the maximum number of iterations has been reached.
+
+   Level: advanced
+
+.seealso: [](ch:nep), `NEPStop`, `NEPSetStoppingTest()`, `NEPStoppingBasic()`
+M*/
+
+/*MC
+   NEP_STOP_USER - The user-provided stopping test.
+
+   Note:
+   Customized stopping test using the user-provided function given with
+   `NEPSetStoppingTestFunction()`.
+
+   Level: advanced
+
+.seealso: [](ch:nep), `NEPStop`, `NEPSetStoppingTest()`, `NEPSetStoppingTestFunction()`
+M*/
+
 /*E
-    NEPConvergedReason - Reason a nonlinear eigensolver was said to
-         have converged or diverged
+   NEPConvergedReason - Reason a nonlinear eigensolver was determined to have converged
+   or diverged.
 
-    Level: intermediate
+   Values:
++  `NEP_CONVERGED_TOL`               - converged up to tolerance
+.  `NEP_CONVERGED_USER`              - converged due to a user-defined condition
+.  `NEP_DIVERGED_ITS`                - exceeded the maximum number of allowed iterations
+.  `NEP_DIVERGED_BREAKDOWN`          - generic breakdown in method
+.  `NEP_DIVERGED_LINEAR_SOLVE`       - inner linear solve failed
+.  `NEP_DIVERGED_SUBSPACE_EXHAUSTED` - run out of space for the basis in an unrestarted solver
+-  `NEP_CONVERGED_ITERATING`         - the solver is still running
 
-.seealso: NEPSolve(), NEPGetConvergedReason(), NEPSetTolerances()
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSolve()`, `NEPGetConvergedReason()`, `NEPSetTolerances()`
 E*/
 typedef enum {/* converged */
               NEP_CONVERGED_TOL                =  1,
@@ -158,6 +252,72 @@ typedef enum {/* converged */
               NEP_CONVERGED_ITERATING          =  0} NEPConvergedReason;
 SLEPC_EXTERN const char *const*NEPConvergedReasons;
 
+/*MC
+   NEP_CONVERGED_TOL - The computed error estimates, based on residual norms,
+   for all requested eigenvalues are below the tolerance.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSolve()`, `NEPGetConvergedReason()`, `NEPConvergedReason`
+M*/
+
+/*MC
+   NEP_CONVERGED_USER - The solver was declared converged due to a user-defined condition.
+
+   Note:
+   This happens only when a user-defined stopping test has been set with
+   `NEPSetStoppingTestFunction()`.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSolve()`, `NEPGetConvergedReason()`, `NEPConvergedReason`, `NEPSetStoppingTestFunction()`
+M*/
+
+/*MC
+   NEP_DIVERGED_ITS - Exceeded the maximum number of allowed iterations
+   before the convergence criterion was satisfied.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSolve()`, `NEPGetConvergedReason()`, `NEPConvergedReason`
+M*/
+
+/*MC
+   NEP_DIVERGED_BREAKDOWN - A breakdown in the solver was detected so the
+   method could not continue.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSolve()`, `NEPGetConvergedReason()`, `NEPConvergedReason`
+M*/
+
+/*MC
+   NEP_DIVERGED_LINEAR_SOLVE - The inner linear solve failed so the nonlinear
+   eigensolver could not continue.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSolve()`, `NEPGetConvergedReason()`, `NEPConvergedReason`
+M*/
+
+/*MC
+   NEP_DIVERGED_SUBSPACE_EXHAUSTED - The solver has run out of space for the
+   basis in the case of an unrestarted method.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSolve()`, `NEPGetConvergedReason()`, `NEPConvergedReason`
+M*/
+
+/*MC
+   NEP_CONVERGED_ITERATING - This value is returned if `NEPGetConvergedReason()` is called
+   while `NEPSolve()` is still running.
+
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPSolve()`, `NEPGetConvergedReason()`, `NEPConvergedReason`
+M*/
+
 SLEPC_EXTERN PetscErrorCode NEPCreate(MPI_Comm,NEP*);
 SLEPC_EXTERN PetscErrorCode NEPDestroy(NEP*);
 SLEPC_EXTERN PetscErrorCode NEPReset(NEP);
@@ -185,35 +345,37 @@ SLEPC_EXTERN PetscErrorCode NEPVectorsView(NEP,PetscViewer);
 SLEPC_EXTERN PetscErrorCode NEPVectorsViewFromOptions(NEP);
 
 /*S
-  NEPFunctionFn - A prototype of a NEP function evaluation function that would be passed to NEPSetFunction()
+   NEPFunctionFn - A prototype of a `NEP` function evaluation function that
+   would be passed to `NEPSetFunction()`.
 
-  Calling Sequence:
-+   nep    - eigensolver context obtained from NEPCreate()
-.   lambda - the scalar argument where T(.) must be evaluated
-.   T      - matrix that will contain T(lambda)
-.   P      - [optional] different matrix to build the preconditioner
--   ctx    - [optional] user-defined context for private data for the
-             function evaluation routine (may be NULL)
+   Calling Sequence:
++  nep    - the nonlinear eigensolver context
+.  lambda - the scalar argument where $T(\cdot)$ must be evaluated
+.  T      - matrix that will contain $T(\lambda)$
+.  P      - [optional] different matrix to build the preconditioner
+-  ctx    - [optional] user-defined context for private data for the
+            function evaluation routine (may be `NULL`)
 
-  Level: beginner
+   Level: beginner
 
-.seealso: NEPSetFunction()
+.seealso: [](ch:nep), `NEPSetFunction()`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPFunctionFn(NEP nep,PetscScalar lambda,Mat T,Mat P,void *ctx);
 
 /*S
-  NEPJacobianFn - A prototype of a NEP Jacobian evaluation function that would be passed to NEPSetJacobian()
+   NEPJacobianFn - A prototype of a `NEP` Jacobian evaluation function that
+   would be passed to `NEPSetJacobian()`.
 
-  Calling Sequence:
-+   nep    - eigensolver context obtained from NEPCreate()
-.   lambda - the scalar argument where T'(.) must be evaluated
-.   J      - matrix that will contain T'(lambda)
--   ctx    - [optional] user-defined context for private data for the
-             Jacobian evaluation routine (may be NULL)
+   Calling Sequence:
++  nep    - the nonlinear eigensolver context
+.  lambda - the scalar argument where $T'(\cdot)$ must be evaluated
+.  J      - matrix that will contain $T'(\lambda)$
+-  ctx    - [optional] user-defined context for private data for the
+            Jacobian evaluation routine (may be `NULL`)
 
-  Level: beginner
+   Level: beginner
 
-.seealso: NEPSetJacobian()
+.seealso: [](ch:nep), `NEPSetJacobian()`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPJacobianFn(NEP nep,PetscScalar lambda,Mat J,void *ctx);
 
@@ -275,74 +437,76 @@ SLEPC_EXTERN PetscErrorCode NEPGetTrackAll(NEP,PetscBool*);
 SLEPC_EXTERN PetscErrorCode NEPGetConvergedReason(NEP,NEPConvergedReason*);
 
 /*S
-  NEPMonitorFn - A function prototype for functions provided to NEPMonitorSet()
+   NEPMonitorFn - A function prototype for functions provided to `NEPMonitorSet()`.
 
-  Calling Sequence:
-+   nep    - eigensolver context obtained from NEPCreate()
-.   its    - iteration number
-.   nconv  - number of converged eigenpairs
-.   eigr   - real part of the eigenvalues
-.   eigi   - imaginary part of the eigenvalues
-.   errest - relative error estimates for each eigenpair
-.   nest   - number of error estimates
--   ctx    - optional monitoring context, as provided with NEPMonitorSet()
+   Calling Sequence:
++  nep    - the nonlinear eigensolver context
+.  its    - iteration number
+.  nconv  - number of converged eigenpairs
+.  eigr   - real part of the eigenvalues
+.  eigi   - imaginary part of the eigenvalues
+.  errest - relative error estimates for each eigenpair
+.  nest   - number of error estimates
+-  ctx    - optional monitoring context, as provided with `NEPMonitorSet()`
 
-  Level: beginner
+   Level: intermediate
 
-.seealso: NEPMonitorSet()
+.seealso: [](ch:nep), `NEPMonitorSet()`
 S*/
-PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPMonitorFn(NEP nep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,void *ctx);
+PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPMonitorFn(NEP nep,PetscInt its,PetscInt nconv,PetscScalar eigr[],PetscScalar eigi[],PetscReal errest[],PetscInt nest,void *ctx);
 
 /*S
-  NEPMonitorRegisterFn - A function prototype for functions provided to NEPMonitorRegister()
+   NEPMonitorRegisterFn - A function prototype for functions provided to `NEPMonitorRegister()`.
 
-  Calling Sequence:
-+   nep    - eigensolver context obtained from NEPCreate()
-.   its    - iteration number
-.   nconv  - number of converged eigenpairs
-.   eigr   - real part of the eigenvalues
-.   eigi   - imaginary part of the eigenvalues
-.   errest - relative error estimates for each eigenpair
-.   nest   - number of error estimates
--   ctx    - PetscViewerAndFormat object
+   Calling Sequence:
++  nep    - the nonlinear eigensolver context
+.  its    - iteration number
+.  nconv  - number of converged eigenpairs
+.  eigr   - real part of the eigenvalues
+.  eigi   - imaginary part of the eigenvalues
+.  errest - relative error estimates for each eigenpair
+.  nest   - number of error estimates
+-  ctx    - `PetscViewerAndFormat` object
 
-  Level: beginner
+   Level: advanced
 
-  Note:
-  This is an NEPMonitorFn specialized for a context of PetscViewerAndFormat.
+   Note:
+   This is a `NEPMonitorFn` specialized for a context of `PetscViewerAndFormat`.
 
-.seealso: NEPMonitorSet(), NEPMonitorRegister(), NEPMonitorFn, NEPMonitorRegisterCreateFn, NEPMonitorRegisterDestroyFn
+.seealso: [](ch:nep), `NEPMonitorSet()`, `NEPMonitorRegister()`, `NEPMonitorFn`, `NEPMonitorRegisterCreateFn`, `NEPMonitorRegisterDestroyFn`
 S*/
-PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPMonitorRegisterFn(NEP nep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *ctx);
+PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPMonitorRegisterFn(NEP nep,PetscInt its,PetscInt nconv,PetscScalar eigr[],PetscScalar eigi[],PetscReal errest[],PetscInt nest,PetscViewerAndFormat *ctx);
 
 /*S
-  NEPMonitorRegisterCreateFn - A function prototype for functions that do the creation when provided to NEPMonitorRegister()
+   NEPMonitorRegisterCreateFn - A function prototype for functions that do the
+   creation when provided to `NEPMonitorRegister()`.
 
-  Calling Sequence:
-+   viewer - the viewer to be used with the NEPMonitorRegisterFn
-.   format - the format of the viewer
-.   ctx    - a context for the monitor
--   result - a PetscViewerAndFormat object
+   Calling Sequence:
++  viewer - the viewer to be used with the `NEPMonitorRegisterFn`
+.  format - the format of the viewer
+.  ctx    - a context for the monitor
+-  result - a `PetscViewerAndFormat` object
 
-  Level: beginner
+   Level: advanced
 
-.seealso: NEPMonitorRegisterFn, NEPMonitorSet(), NEPMonitorRegister(), NEPMonitorFn, NEPMonitorRegisterDestroyFn
+.seealso: [](ch:nep), `NEPMonitorRegisterFn`, `NEPMonitorSet()`, `NEPMonitorRegister()`, `NEPMonitorFn`, `NEPMonitorRegisterDestroyFn`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPMonitorRegisterCreateFn(PetscViewer viewer,PetscViewerFormat format,void *ctx,PetscViewerAndFormat **result);
 
 /*S
-  NEPMonitorRegisterDestroyFn - A function prototype for functions that do the after use destruction when provided to NEPMonitorRegister()
+   NEPMonitorRegisterDestroyFn - A function prototype for functions that do the after
+   use destruction when provided to `NEPMonitorRegister()`.
 
-  Calling Sequence:
-.   vf - a PetscViewerAndFormat object to be destroyed, including any context
+   Calling Sequence:
+.  vf - a `PetscViewerAndFormat` object to be destroyed, including any context
 
-  Level: beginner
+   Level: advanced
 
-.seealso: NEPMonitorRegisterFn, NEPMonitorSet(), NEPMonitorRegister(), NEPMonitorFn, NEPMonitorRegisterCreateFn
+.seealso: [](ch:nep), `NEPMonitorRegisterFn`, `NEPMonitorSet()`, `NEPMonitorRegister()`, `NEPMonitorFn`, `NEPMonitorRegisterCreateFn`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPMonitorRegisterDestroyFn(PetscViewerAndFormat **result);
 
-SLEPC_EXTERN PetscErrorCode NEPMonitor(NEP,PetscInt,PetscInt,PetscScalar*,PetscScalar*,PetscReal*,PetscInt);
+SLEPC_EXTERN PetscErrorCode NEPMonitor(NEP,PetscInt,PetscInt,PetscScalar[],PetscScalar[],PetscReal[],PetscInt);
 SLEPC_EXTERN PetscErrorCode NEPMonitorSet(NEP,NEPMonitorFn,void*,PetscCtxDestroyFn*);
 SLEPC_EXTERN PetscErrorCode NEPMonitorCancel(NEP);
 SLEPC_EXTERN PetscErrorCode NEPGetMonitorContext(NEP,void*);
@@ -360,8 +524,8 @@ SLEPC_EXTERN NEPMonitorRegisterFn        NEPMonitorConvergedDrawLG;
 SLEPC_EXTERN NEPMonitorRegisterCreateFn  NEPMonitorConvergedDrawLGCreate;
 SLEPC_EXTERN NEPMonitorRegisterDestroyFn NEPMonitorConvergedDestroy;
 
-SLEPC_EXTERN PetscErrorCode NEPSetOptionsPrefix(NEP,const char*);
-SLEPC_EXTERN PetscErrorCode NEPAppendOptionsPrefix(NEP,const char*);
+SLEPC_EXTERN PetscErrorCode NEPSetOptionsPrefix(NEP,const char[]);
+SLEPC_EXTERN PetscErrorCode NEPAppendOptionsPrefix(NEP,const char[]);
 SLEPC_EXTERN PetscErrorCode NEPGetOptionsPrefix(NEP,const char*[]);
 
 SLEPC_EXTERN PetscFunctionList NEPList;
@@ -375,20 +539,20 @@ SLEPC_EXTERN PetscErrorCode NEPSetWorkVecs(NEP,PetscInt);
 SLEPC_EXTERN PetscErrorCode NEPAllocateSolution(NEP,PetscInt);
 
 /*S
-  NEPConvergenceTestFn - A prototype of a NEP convergence test function that would be passed to NEPSetConvergenceTestFunction()
+   NEPConvergenceTestFn - A prototype of a `NEP` convergence test function that
+   would be passed to `NEPSetConvergenceTestFunction()`.
 
-  Calling Sequence:
-+   nep    - eigensolver context obtained from NEPCreate()
-.   eigr   - real part of the eigenvalue
-.   eigi   - imaginary part of the eigenvalue
-.   res    - residual norm associated to the eigenpair
-.   errest - [output] computed error estimate
--   ctx    - [optional] user-defined context for private data for the
-             convergence test routine (may be NULL)
+   Calling Sequence:
++  nep    - the nonlinear eigensolver context
+.  eigr   - real part of the eigenvalue
+.  eigi   - imaginary part of the eigenvalue
+.  res    - residual norm associated to the eigenpair
+.  errest - [output] computed error estimate
+-  ctx    - optional convergence context, as set by `NEPSetConvergenceTestFunction()`
 
-  Level: advanced
+   Level: advanced
 
-.seealso: NEPSetConvergenceTestFunction()
+.seealso: [](ch:nep), `NEPSetConvergenceTest()`, `NEPSetConvergenceTestFunction()`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPConvergenceTestFn(NEP nep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx);
 
@@ -400,21 +564,27 @@ SLEPC_EXTERN NEPConvergenceTestFn NEPConvergedNorm;
 SLEPC_EXTERN PetscErrorCode NEPSetConvergenceTestFunction(NEP,NEPConvergenceTestFn*,void*,PetscCtxDestroyFn*);
 
 /*S
-  NEPStoppingTestFn - A prototype of a NEP stopping test function that would be passed to NEPSetStoppingTestFunction()
+   NEPStoppingTestFn - A prototype of a `NEP` stopping test function that would
+   be passed to `NEPSetStoppingTestFunction()`.
 
-  Calling Sequence:
-+   nep    - eigensolver context obtained from NEPCreate()
-.   its    - current number of iterations
-.   max_it - maximum number of iterations
-.   nconv  - number of currently converged eigenpairs
-.   nev    - number of requested eigenpairs
-.   reason - [output] result of the stopping test
--   ctx    - [optional] user-defined context for private data for the
-             stopping test routine (may be NULL)
+   Calling Sequence:
++  nep    - the nonlinear eigensolver context
+.  its    - current number of iterations
+.  max_it - maximum number of iterations
+.  nconv  - number of currently converged eigenpairs
+.  nev    - number of requested eigenpairs
+.  reason - [output] result of the stopping test
+-  ctx    - optional stopping context, as set by `NEPSetStoppingTestFunction()`
 
-  Level: advanced
+   Note:
+   A positive value of `reason` indicates that the iteration has finished successfully
+   (converged), and a negative value indicates an error condition (diverged). If
+   the iteration needs to be continued, `reason` must be set to `NEP_CONVERGED_ITERATING`
+   (zero).
 
-.seealso: NEPSetStoppingTestFunction()
+   Level: advanced
+
+.seealso: [](ch:nep), `NEPSetStoppingTestFunction()`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPStoppingTestFn(NEP nep,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,NEPConvergedReason *reason,void *ctx);
 
@@ -455,11 +625,16 @@ SLEPC_EXTERN PetscErrorCode NEPNArnoldiSetLagPreconditioner(NEP,PetscInt);
 SLEPC_EXTERN PetscErrorCode NEPNArnoldiGetLagPreconditioner(NEP,PetscInt*);
 
 /*E
-    NEPCISSExtraction - determines the extraction technique in the CISS solver
+   NEPCISSExtraction - The extraction technique used in the CISS solver.
 
-    Level: advanced
+   Values:
++  `NEP_CISS_EXTRACTION_RITZ`   - Rayleigh-Ritz extraction
+.  `NEP_CISS_EXTRACTION_HANKEL` - block Hankel method
+-  `NEP_CISS_EXTRACTION_CAA`    - communication-avoiding Arnoldi method
 
-.seealso: NEPCISSSetExtraction(), NEPCISSGetExtraction()
+   Level: advanced
+
+.seealso: [](ch:nep), `NEPCISSSetExtraction()`, `NEPCISSGetExtraction()`
 E*/
 typedef enum { NEP_CISS_EXTRACTION_RITZ,
                NEP_CISS_EXTRACTION_HANKEL,
@@ -499,17 +674,22 @@ SLEPC_EXTERN PetscErrorCode NEPInterpolSetInterpolation(NEP,PetscReal,PetscInt);
 SLEPC_EXTERN PetscErrorCode NEPInterpolGetInterpolation(NEP,PetscReal*,PetscInt*);
 
 /*S
-  NEPNLEIGSSingularitiesFn - A prototype of a function that would be passed to NEPNLEIGSSetSingularitiesFunction()
+   NEPNLEIGSSingularitiesFn - A prototype of a function that would be passed
+   to `NEPNLEIGSSetSingularitiesFunction()`.
 
-  Calling Sequence:
-+   nep   - eigensolver context obtained from NEPCreate()
-.   maxnp - on input number of requested points in the discretization (can be set)
-.   xi    - computed values of the discretization
--   ctx   - optional context, as set by NEPNLEIGSSetSingularitiesFunction()
+   Calling Sequence:
++  nep   - the nonlinear eigensolver context
+.  maxnp - on input the number of requested points in the discretization (can be modified)
+.  xi    - computed values of the discretization
+-  ctx   - optional context, as set by `NEPNLEIGSSetSingularitiesFunction()`
 
-  Level: advanced
+   Note:
+   The user-defined function can set a smaller value of `maxnp` if necessary.
+   It is wrong to return a larger value.
 
-.seealso: NEPNLEIGSSetSingularitiesFunction()
+   Level: intermediate
+
+.seealso: [](ch:nep), `NEPNLEIGSSetSingularitiesFunction()`
 S*/
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode NEPNLEIGSSingularitiesFn(NEP nep,PetscInt *maxnp,PetscScalar *xi,void *ctx);
 
