@@ -8,8 +8,7 @@
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-#if !defined(SLEPCRGTYPES_H)
-#define SLEPCRGTYPES_H
+#pragma once
 
 /* SUBMANSEC = RG */
 
@@ -18,8 +17,6 @@
 
    Level: beginner
 
-.seealso: RGCreate()
+.seealso: [](sec:rg), `RGCreate()`
 S*/
 typedef struct _p_RG* RG;
-
-#endif
