@@ -12,12 +12,11 @@
    by all other SLEPc include files.
 */
 
-#if !defined(SLEPCSYS_H)
-#define SLEPCSYS_H
+#pragma once
 
 #include <petscsys.h>
 
-/* SUBMANSEC = sys */
+/* SUBMANSEC = Sys */
 
 #if defined(slepc_EXPORTS)
 #define SLEPC_VISIBILITY_PUBLIC PETSC_DLLEXPORT
@@ -39,6 +38,14 @@
 #define SLEPC_INTERN extern SLEPC_VISIBILITY_INTERNAL
 #endif
 
+#if defined(PETSC_USE_SINGLE_LIBRARY)
+  #define SLEPC_SINGLE_LIBRARY_VISIBILITY_INTERNAL SLEPC_VISIBILITY_INTERNAL
+  #define SLEPC_SINGLE_LIBRARY_INTERN              SLEPC_INTERN
+#else
+  #define SLEPC_SINGLE_LIBRARY_VISIBILITY_INTERNAL SLEPC_VISIBILITY_PUBLIC
+  #define SLEPC_SINGLE_LIBRARY_INTERN              SLEPC_EXTERN
+#endif
+
 /* ========================================================================== */
 /*
    slepcconf.h is created by the configure script and placed in ${PETSC_ARCH}/include.
@@ -89,7 +96,7 @@ SLEPC_EXTERN PetscErrorCode SlepcGetVersion(char[],size_t);
 SLEPC_EXTERN PetscErrorCode SlepcGetVersionNumber(PetscInt*,PetscInt*,PetscInt*,PetscInt*);
 SLEPC_EXTERN PetscErrorCode SlepcHasExternalPackage(const char[],PetscBool*);
 
-SLEPC_EXTERN PetscErrorCode SlepcSNPrintfScalar(char*,size_t,PetscScalar,PetscBool);
+SLEPC_EXTERN PetscErrorCode SlepcSNPrintfScalar(char[],size_t,PetscScalar,PetscBool);
 
 SLEPC_EXTERN PetscBool SlepcInitializeCalled;
 SLEPC_EXTERN PetscBool SlepcFinalizeCalled;
@@ -112,5 +119,3 @@ SLEPC_EXTERN PetscBool SlepcFinalizeCalled;
 #if defined(PETSC_USE_DEBUG)
 SLEPC_EXTERN PetscErrorCode SlepcDebugViewMatrix(PetscInt,PetscInt,PetscScalar*,PetscScalar*,PetscInt,const char*,const char*);
 #endif
-#endif
-
