@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-#!/bin/env python3
 #
 #    Generates etag and ctag (use -noctags to skip generation of ctags) files for SLEPc
 #    Adds file names to list of tags in a TAGS file
@@ -59,7 +58,7 @@ def createTagsBlock(flist,etagfile,ctagfile):
 
   # linux can use '--tag-relative=yes --langmap=c:+.cu'. For others [Mac,bsd] try running ctags in root directory - with relative path to file
   if ctagfile:
-    status = subprocess.call('ctags --fields=+l --tag-relative=yes --langmap=c:+.cu  -a -f '+ctagfile+' '+' '.join(frlist), shell=True, stdout=DEVNULL, stderr=subprocess.STDOUT)
+    status = subprocess.call('ctags --fields=+l --tag-relative=yes --langmap=c:+.cu -I PeNS,PeOP -a -f '+ctagfile+' '+' '.join(frlist), shell=True, stdout=DEVNULL, stderr=subprocess.STDOUT)
     if status:
       status = subprocess.call('/usr/local/bin/ctags -a -f '+ctagfile+' '+' '.join(frlist), shell=True, stdout=DEVNULL, stderr=subprocess.STDOUT)
       if status:
@@ -147,7 +146,7 @@ def main(ctags):
     ctagfile = None
   flist = []
   if os.path.isdir('.git'):
-    output = subprocess.check_output('git ls-files | grep -E -v \(^\(docs/\|share/slepc/datafiles/\)\|/output/\|\.\(png\|pdf\|ps\|ppt\|jpg\|tex\)$\)', shell=True)
+    output = subprocess.check_output(r'git ls-files | grep -E -v \(^\(docs/\|share/slepc/datafiles/\)\|/output/\|\.\(png\|pdf\|ps\|ppt\|jpg\|tex\)$\)', shell=True)
     flist = output.decode(sys.getfilesystemencoding()).splitlines()
   else:
     for dirpath, dirnames, filenames in os.walk(os.getcwd()):
