@@ -42,11 +42,11 @@ static PetscErrorCode EPSSetUp_RQCG(EPS eps)
   PetscFunctionBegin;
   EPSCheckHermitianDefinite(eps);
   EPSCheckNotStructured(eps);
-  PetscCall(EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd));
+  PetscCall(EPSSetDimensions_Default(eps,&eps->nev,&eps->ncv,&eps->mpd));
   if (eps->max_it==PETSC_DETERMINE) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
   if (!eps->which) eps->which = EPS_SMALLEST_REAL;
   PetscCheck(eps->which==EPS_SMALLEST_REAL,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver supports only smallest real eigenvalues");
-  EPSCheckUnsupported(eps,EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_EXTRACTION);
+  EPSCheckUnsupported(eps,EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_EXTRACTION | EPS_FEATURE_THRESHOLD);
   EPSCheckIgnored(eps,EPS_FEATURE_BALANCE);
 
   if (!ctx->nrest) ctx->nrest = 20;
@@ -257,21 +257,24 @@ static PetscErrorCode EPSRQCGSetReset_RQCG(EPS eps,PetscInt nrest)
 }
 
 /*@
-   EPSRQCGSetReset - Sets the reset parameter of the RQCG iteration. Every
-   nrest iterations, the solver performs a Rayleigh-Ritz projection step.
+   EPSRQCGSetReset - Sets the reset parameter of the RQCG iteration.
 
    Logically Collective
 
    Input Parameters:
-+  eps - the eigenproblem solver context
++  eps - the linear eigensolver context
 -  nrest - the number of iterations between resets
 
    Options Database Key:
-.  -eps_rqcg_reset - Sets the reset parameter
+.  -eps_rqcg_reset \<nrest\> - sets the reset parameter
+
+   Note:
+   The meaning of the reset parameter is that every `nrest` iterations the
+   solver performs a Rayleigh-Ritz projection step.
 
    Level: advanced
 
-.seealso: EPSRQCGGetReset()
+.seealso: [](ch:eps), `EPSRQCG`, `EPSRQCGGetReset()`
 @*/
 PetscErrorCode EPSRQCGSetReset(EPS eps,PetscInt nrest)
 {
@@ -297,14 +300,14 @@ static PetscErrorCode EPSRQCGGetReset_RQCG(EPS eps,PetscInt *nrest)
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  nrest - the reset parameter
 
    Level: advanced
 
-.seealso: EPSRQCGSetReset()
+.seealso: [](ch:eps), `EPSRQCG`, `EPSRQCGSetReset()`
 @*/
 PetscErrorCode EPSRQCGGetReset(EPS eps,PetscInt *nrest)
 {
@@ -328,7 +331,7 @@ static PetscErrorCode EPSReset_RQCG(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode EPSSetFromOptions_RQCG(EPS eps,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode EPSSetFromOptions_RQCG(EPS eps,PetscOptionItems PetscOptionsObject)
 {
   PetscBool      flg;
   PetscInt       nrest;
@@ -363,6 +366,22 @@ static PetscErrorCode EPSView_RQCG(EPS eps,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   EPSRQCG - EPSRQCG = "rqcg" - The Rayleigh Quotient Conjugate Gradient method.
+
+   Notes:
+   This is a preconditioned eigensolver for computing leftmost
+   eigenvalues, similar to `EPSLOBPCG`, but usually less competitive.
+
+   The description of the method is in {cite:p}`Ber06`
+
+   The preconditioner is specified via the internal `ST` object and its
+   associated `KSP`.
+
+   Level: beginner
+
+.seealso: [](ch:eps), `EPS`, `EPSType`, `EPSSetType()`, `EPSGetST()`
+M*/
 SLEPC_EXTERN PetscErrorCode EPSCreate_RQCG(EPS eps)
 {
   EPS_RQCG       *rqcg;
