@@ -279,20 +279,22 @@ static PetscErrorCode EPSEVSLSetSlices_EVSL(EPS eps,PetscInt nslices)
    Logically Collective
 
    Input Parameters:
-+  eps     - the eigensolver context
++  eps     - the linear eigensolver context
 -  nslices - the number of slices
 
    Options Database Key:
-.  -eps_evsl_slices <n> - set the number of slices to n
+.  -eps_evsl_slices \<nslices\> - set the number of slices
 
    Notes:
    By default, one slice per MPI process is used. Depending on the number of
    eigenvalues, using more slices may be beneficial, but very narrow subintervals
    imply higher polynomial degree.
 
-   Level: intermediate
+   See the documentation of EVSL {cite:p}`Li19` for details.
 
-.seealso: EPSEVSLGetSlices()
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSEVSL`, `EPSEVSLGetSlices()`
 @*/
 PetscErrorCode EPSEVSLSetSlices(EPS eps,PetscInt nslices)
 {
@@ -319,14 +321,14 @@ static PetscErrorCode EPSEVSLGetSlices_EVSL(EPS eps,PetscInt *nslices)
    Not Collective
 
    Input Parameter:
-.  eps - the eigensolver context
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  nslices - the number of slices
 
-   Level: intermediate
+   Level: advanced
 
-.seealso: EPSEVSLSetSlices()
+.seealso: [](ch:eps), `EPSEVSL`, `EPSEVSLSetSlices()`
 @*/
 PetscErrorCode EPSEVSLGetSlices(EPS eps,PetscInt *nslices)
 {
@@ -358,24 +360,26 @@ static PetscErrorCode EPSEVSLSetRange_EVSL(EPS eps,PetscReal lmin,PetscReal lmax
    Logically Collective
 
    Input Parameters:
-+  eps  - the eigensolver context
++  eps  - the linear eigensolver context
 .  lmin - left end of the interval
 -  lmax - right end of the interval
 
    Options Database Key:
-.  -eps_evsl_range <a,b> - set [a,b] as the numerical range
+.  -eps_evsl_range <lmin,lmax> - set $[\lambda_\mathrm{min},\lambda_\mathrm{max}]$ as the numerical range
 
    Notes:
-   The filter will be most effective if the numerical range is tight, that is, lmin
-   and lmax are good approximations to the leftmost and rightmost eigenvalues,
+   The filter will be most effective if the numerical range is tight, that is, `lmin`
+   and `lmax` are good approximations to the leftmost and rightmost eigenvalues,
    respectively. If not set by the user, an approximation is computed internally.
 
-   The wanted computational interval specified via EPSSetInterval() must be
+   The wanted computational interval specified via `EPSSetInterval()` must be
    contained in the numerical range.
 
-   Level: intermediate
+   See the documentation of EVSL {cite:p}`Li19` for details.
 
-.seealso: EPSEVSLGetRange(), EPSSetInterval()
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSEVSL`, `EPSEVSLGetRange()`, `EPSSetInterval()`
 @*/
 PetscErrorCode EPSEVSLSetRange(EPS eps,PetscReal lmin,PetscReal lmax)
 {
@@ -403,15 +407,15 @@ static PetscErrorCode EPSEVSLGetRange_EVSL(EPS eps,PetscReal *lmin,PetscReal *lm
    Not Collective
 
    Input Parameter:
-.  eps - the eigensolver context
+.  eps - the linear eigensolver context
 
    Output Parameters:
 +  lmin - left end of the interval
 -  lmax - right end of the interval
 
-   Level: intermediate
+   Level: advanced
 
-.seealso: EPSEVSLSetRange()
+.seealso: [](ch:eps), `EPSEVSL`, `EPSEVSLSetRange()`
 @*/
 PetscErrorCode EPSEVSLGetRange(EPS eps,PetscReal *lmin,PetscReal *lmax)
 {
@@ -464,32 +468,34 @@ static PetscErrorCode EPSEVSLSetDOSParameters_EVSL(EPS eps,EPSEVSLDOSMethod dos,
    Logically Collective
 
    Input Parameters:
-+  eps     - the eigensolver context
-.  dos     - DOS method, either KPM or Lanczos
++  eps     - the linear eigensolver context
+.  dos     - DOS method, see `EPSEVSLDOSMethod` for possible values
 .  nvec    - number of sample vectors
 .  deg     - polynomial degree (KPM only)
 .  steps   - number of Lanczos steps (Lanczos only)
 -  npoints - number of sample points (Lanczos only)
 
    Options Database Keys:
-+  -eps_evsl_dos_method <dos> - set the DOS method, either kpm or lanczos
-.  -eps_evsl_dos_nvec <n> - set the number of sample vectors
-.  -eps_evsl_dos_degree <n> - set the polynomial degree
-.  -eps_evsl_dos_steps <n> - set the number of Lanczos steps
--  -eps_evsl_dos_npoints <n> - set the number of sample points
++  -eps_evsl_dos_method \<dos\>       - set the DOS method, either `kpm` or `lanczos`
+.  -eps_evsl_dos_nvec \<nvec\>        - set the number of sample vectors
+.  -eps_evsl_dos_degree \<deg\>       - set the polynomial degree
+.  -eps_evsl_dos_steps \<steps\>      - set the number of Lanczos steps
+-  -eps_evsl_dos_npoints \<npoints\>  - set the number of sample points
 
    Notes:
    The density of states (or spectral density) can be approximated with two
-   methods, kernel polynomial method (KPM) or Lanczos. Some parameters for
+   methods, Kernel Polynomial Method (KPM) or Lanczos. Some parameters for
    these methods can be set by the user with this function, with some of
    them being relevant for one of the methods only.
 
-   For the integer argumens, you can use PETSC_CURRENT to keep the current
-   value, and PETSC_DETERMINE to set them to a reasonable default.
+   For the integer argumens, you can use `PETSC_CURRENT` to keep the current
+   value, and `PETSC_DETERMINE` to set them to a reasonable default.
 
-   Level: intermediate
+   See the documentation of EVSL {cite:p}`Li19` for details.
 
-.seealso: EPSEVSLGetDOSParameters()
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSEVSL`, `EPSEVSLGetDOSParameters()`, `EPSEVSLDOSMethod`
 @*/
 PetscErrorCode EPSEVSLSetDOSParameters(EPS eps,EPSEVSLDOSMethod dos,PetscInt nvec,PetscInt deg,PetscInt steps,PetscInt npoints)
 {
@@ -524,18 +530,18 @@ static PetscErrorCode EPSEVSLGetDOSParameters_EVSL(EPS eps,EPSEVSLDOSMethod *dos
    Not Collective
 
    Input Parameter:
-.  eps - the eigensolver context
+.  eps - the linear eigensolver context
 
    Output Parameters:
-+  dos     - DOS method, either KPM or Lanczos
++  dos     - DOS method
 .  nvec    - number of sample vectors
 .  deg     - polynomial degree (KPM only)
 .  steps   - number of Lanczos steps (Lanczos only)
 -  npoints - number of sample points (Lanczos only)
 
-   Level: intermediate
+   Level: advanced
 
-.seealso: EPSEVSLSetDOSParameters()
+.seealso: [](ch:eps), `EPSEVSL`, `EPSEVSLSetDOSParameters()`
 @*/
 PetscErrorCode EPSEVSLGetDOSParameters(EPS eps,EPSEVSLDOSMethod *dos,PetscInt *nvec,PetscInt *deg,PetscInt *steps,PetscInt *npoints)
 {
@@ -571,21 +577,23 @@ static PetscErrorCode EPSEVSLSetPolParameters_EVSL(EPS eps,PetscInt max_deg,Pets
    Logically Collective
 
    Input Parameters:
-+  eps     - the eigensolver context
++  eps     - the linear eigensolver context
 .  max_deg - maximum degree allowed for the polynomial
--  thresh  - threshold for accepting polynomial
+-  thresh  - threshold for accepting a value
 
    Options Database Keys:
-+  -eps_evsl_pol_max_deg <d> - set maximum polynomial degree
--  -eps_evsl_pol_thresh <t> - set the threshold
++  -eps_evsl_pol_max_deg \<max_deg\> - set maximum polynomial degree
+-  -eps_evsl_pol_thresh \<thresh\>   - set the threshold
 
-   Note:
-   PETSC_CURRENT can be used to preserve the current value of any of the
-   arguments, and PETSC_DETERMINE to set them to a default value.
+   Notes:
+   `PETSC_CURRENT` can be used to preserve the current value of any of the
+   arguments, and `PETSC_DETERMINE` to set them to a default value.
 
-   Level: intermediate
+   See the documentation of EVSL {cite:p}`Li19` for details.
 
-.seealso: EPSEVSLGetPolParameters()
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSEVSL`, `EPSEVSLGetPolParameters()`
 @*/
 PetscErrorCode EPSEVSLSetPolParameters(EPS eps,PetscInt max_deg,PetscReal thresh)
 {
@@ -614,15 +622,15 @@ static PetscErrorCode EPSEVSLGetPolParameters_EVSL(EPS eps,PetscInt *max_deg,Pet
    Not Collective
 
    Input Parameter:
-.  eps - the eigensolver context
+.  eps - the linear eigensolver context
 
    Output Parameters:
 +  max_deg - the maximum degree of the polynomial
 -  thresh  - the threshold
 
-   Level: intermediate
+   Level: advanced
 
-.seealso: EPSEVSLSetPolParameters()
+.seealso: [](ch:eps), `EPSEVSL`, `EPSEVSLSetPolParameters()`
 @*/
 PetscErrorCode EPSEVSLGetPolParameters(EPS eps,PetscInt *max_deg,PetscReal *thresh)
 {
@@ -650,19 +658,21 @@ static PetscErrorCode EPSEVSLSetDamping_EVSL(EPS eps,EPSEVSLDamping damping)
    Logically Collective
 
    Input Parameters:
-+  eps     - the eigensolver context
--  damping - the type of damping
++  eps     - the linear eigensolver context
+-  damping - the type of damping, see `EPSEVSLDamping` for possible values
 
    Options Database Key:
-.  -eps_evsl_damping <n> - set the type of damping
+.  -eps_evsl_damping \<damping\> - set the type of damping
 
    Notes:
    Damping is applied when building the polynomial to be used when solving the
-   eigenproblem, and also during estimation of DOS with the KPM method.
+   eigenproblem, and also during estimation of the DOS with the KPM method.
 
-   Level: intermediate
+   See the documentation of EVSL {cite:p}`Li19` for details.
 
-.seealso: EPSEVSLGetDamping(), EPSEVSLSetDOSParameters()
+   Level: advanced
+
+.seealso: [](ch:eps), `EPSEVSL`, `EPSEVSLGetDamping()`, `EPSEVSLSetDOSParameters()`
 @*/
 PetscErrorCode EPSEVSLSetDamping(EPS eps,EPSEVSLDamping damping)
 {
@@ -688,14 +698,14 @@ static PetscErrorCode EPSEVSLGetDamping_EVSL(EPS eps,EPSEVSLDamping *damping)
    Not Collective
 
    Input Parameter:
-.  eps - the eigensolver context
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  damping - the type of damping
 
-   Level: intermediate
+   Level: advanced
 
-.seealso: EPSEVSLSetDamping()
+.seealso: [](ch:eps), `EPSEVSL`, `EPSEVSLSetDamping()`
 @*/
 PetscErrorCode EPSEVSLGetDamping(EPS eps,EPSEVSLDamping *damping)
 {
@@ -811,6 +821,19 @@ static PetscErrorCode EPSReset_EVSL(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   EPSEVSL - EPSEVSL = "evsl" - A wrapper to EVSL {cite:p}`Li19`.
+
+   Note:
+   The Eigenvalues Slicing Library {EVSL} is intended for the case that
+   all eigenvalues inside a given interval are requested, for Hermitian
+   problems. It is based on polynomial filters, and has similarities with
+   the algorithms implemented in `STFILTER`.
+
+   Level: beginner
+
+.seealso: [](ch:eps), `EPS`, `EPSType`, `EPSSetType()`
+M*/
 SLEPC_EXTERN PetscErrorCode EPSCreate_EVSL(EPS eps)
 {
   EPS_EVSL       *ctx;
