@@ -274,15 +274,15 @@ static PetscErrorCode EPSFEASTSetNumPoints_FEAST(EPS eps,PetscInt npoints)
    Logically Collective
 
    Input Parameters:
-+  eps     - the eigenproblem solver context
++  eps     - the linear eigensolver context
 -  npoints - number of contour integration points
 
    Options Database Key:
-.  -eps_feast_num_points - Sets the number of points
+.  -eps_feast_num_points \<npoints\> - sets the number of points
 
    Level: advanced
 
-.seealso: EPSFEASTGetNumPoints()
+.seealso: [](ch:eps), `EPSFEAST`, `EPSFEASTGetNumPoints()`
 @*/
 PetscErrorCode EPSFEASTSetNumPoints(EPS eps,PetscInt npoints)
 {
@@ -309,14 +309,14 @@ static PetscErrorCode EPSFEASTGetNumPoints_FEAST(EPS eps,PetscInt *npoints)
    Not Collective
 
    Input Parameter:
-.  eps     - the eigenproblem solver context
+.  eps     - the linear eigensolver context
 
    Output Parameter:
 .  npoints - number of contour integration points
 
    Level: advanced
 
-.seealso: EPSFEASTSetNumPoints()
+.seealso: [](ch:eps), `EPSFEAST`, `EPSFEASTSetNumPoints()`
 @*/
 PetscErrorCode EPSFEASTGetNumPoints(EPS eps,PetscInt *npoints)
 {
@@ -327,6 +327,17 @@ PetscErrorCode EPSFEASTGetNumPoints(EPS eps,PetscInt *npoints)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   EPSFEAST - EPSFEAST = "feast" - A wrapper to FEAST {cite:p}`Pol09`.
+
+   Note:
+   We currently support only the implementation of FEAST that is included
+   in the Intel MKL library.
+
+   Level: beginner
+
+.seealso: [](ch:eps), `EPS`, `EPSType`, `EPSSetType()`
+M*/
 SLEPC_EXTERN PetscErrorCode EPSCreate_FEAST(EPS eps)
 {
   EPS_FEAST      *ctx;
