@@ -43,12 +43,12 @@ static PetscErrorCode EPSSetUp_Lanczos(EPS eps)
   PetscFunctionBegin;
   EPSCheckHermitianDefinite(eps);
   EPSCheckNotStructured(eps);
-  PetscCall(EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd));
+  PetscCall(EPSSetDimensions_Default(eps,&eps->nev,&eps->ncv,&eps->mpd));
   PetscCheck(eps->ncv<=eps->nev+eps->mpd,PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
   if (eps->max_it==PETSC_DETERMINE) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
   if (!eps->which) PetscCall(EPSSetWhichEigenpairs_Default(eps));
   PetscCheck(eps->which!=EPS_ALL,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support computing all eigenvalues");
-  EPSCheckUnsupported(eps,EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_EXTRACTION);
+  EPSCheckUnsupported(eps,EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_EXTRACTION | EPS_FEATURE_THRESHOLD);
   EPSCheckIgnored(eps,EPS_FEATURE_BALANCE);
 
   PetscCheck(lanczos->reorthog!=(EPSLanczosReorthogType)-1,PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"You should explicitly provide the reorthogonalization type, e.g., -eps_lanczos_reorthog local. Note that the EPSLANCZOS solver is *NOT RECOMMENDED* for general use, because it uses explicit restart which typically has slow convergence. The recommended solver is EPSKRYLOVSCHUR (the default), which implements Lanczos with thick restart in the case of symmetric/Hermitian problems");
@@ -696,7 +696,7 @@ static PetscErrorCode EPSSolve_Lanczos(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode EPSSetFromOptions_Lanczos(EPS eps,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode EPSSetFromOptions_Lanczos(EPS eps,PetscOptionItems PetscOptionsObject)
 {
   EPS_LANCZOS            *lanczos = (EPS_LANCZOS*)eps->data;
   PetscBool              flg;
@@ -743,16 +743,21 @@ static PetscErrorCode EPSLanczosSetReorthog_Lanczos(EPS eps,EPSLanczosReorthogTy
    Logically Collective
 
    Input Parameters:
-+  eps - the eigenproblem solver context
--  reorthog - the type of reorthogonalization
++  eps - the linear eigensolver context
+-  reorthog - the type of reorthogonalization, see `EPSLanczosReorthogType` for possible values
 
    Options Database Key:
-.  -eps_lanczos_reorthog - Sets the reorthogonalization type (either 'local', 'selective',
-                         'periodic', 'partial', 'full' or 'delayed')
+.  -eps_lanczos_reorthog \<reorthog\> - sets the reorthogonalization type
+
+   Notes:
+   Details of the different reorthogonalization strategies can be found in
+   {cite:p}`Her06`.
+
+   This applies to `EPSLANCZOS`, not to `EPSKRYLOVSCHUR`.
 
    Level: advanced
 
-.seealso: EPSLanczosGetReorthog(), EPSLanczosReorthogType
+.seealso: [](ch:eps), `EPSLANCZOS`, `EPSLanczosGetReorthog()`, `EPSLanczosReorthogType`
 @*/
 PetscErrorCode EPSLanczosSetReorthog(EPS eps,EPSLanczosReorthogType reorthog)
 {
@@ -779,14 +784,14 @@ static PetscErrorCode EPSLanczosGetReorthog_Lanczos(EPS eps,EPSLanczosReorthogTy
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  reorthog - the type of reorthogonalization
 
    Level: advanced
 
-.seealso: EPSLanczosSetReorthog(), EPSLanczosReorthogType
+.seealso: [](ch:eps), `EPSLANCZOS`, `EPSLanczosSetReorthog()`, `EPSLanczosReorthogType`
 @*/
 PetscErrorCode EPSLanczosGetReorthog(EPS eps,EPSLanczosReorthogType *reorthog)
 {
@@ -829,6 +834,26 @@ static PetscErrorCode EPSView_Lanczos(EPS eps,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   EPSLANCZOS - EPSLANCZOS = "lanczos" - A basic Krylov method for Hermitian
+   problems, with explicit restart.
+
+   Notes:
+   This solver is very basic and is not recommended in general, since it
+   will not be competitive with respect to other solvers.
+
+   The implemented method is Lanczos with explicit restart and deflation.
+   Generally, it is much better to use Lanczos with implicit restart (also
+   known as thick-restart Lanczos) as implemented in `EPSKRYLOVSCHUR`.
+
+   Several reorthogonalization strategies can be selected with `EPSLanczosSetReorthog()`.
+   Some of them may result in a cheaper computation, but it will seldom be
+   enough to beat `EPSKRYLOVSCHUR`.
+
+   Level: beginner
+
+.seealso: [](ch:eps), `EPS`, `EPSType`, `EPSSetType()`, `EPSLanczosSetReorthog()`
+M*/
 SLEPC_EXTERN PetscErrorCode EPSCreate_Lanczos(EPS eps)
 {
   EPS_LANCZOS    *ctx;
