@@ -25,13 +25,15 @@ static PetscErrorCode EPSSetUp_LAPACK(EPS eps)
   PC             pc;
 
   PetscFunctionBegin;
+  EPSCheckNotStructured(eps);
+  if (eps->nev==0) eps->nev = 1;
   eps->ncv = eps->n;
   if (eps->mpd!=PETSC_DETERMINE) PetscCall(PetscInfo(eps,"Warning: parameter mpd ignored\n"));
   if (eps->max_it==PETSC_DETERMINE) eps->max_it = 1;
   if (!eps->which) PetscCall(EPSSetWhichEigenpairs_Default(eps));
   PetscCheck(eps->which!=EPS_ALL || eps->inta==eps->intb,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support interval computation");
-  EPSCheckUnsupported(eps,EPS_FEATURE_BALANCE | EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_STOPPING);
-  EPSCheckIgnored(eps,EPS_FEATURE_EXTRACTION | EPS_FEATURE_CONVERGENCE);
+  EPSCheckUnsupported(eps,EPS_FEATURE_BALANCE | EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION);
+  EPSCheckIgnored(eps,EPS_FEATURE_EXTRACTION | EPS_FEATURE_CONVERGENCE | EPS_FEATURE_STOPPING);
   PetscCall(EPSAllocateSolution(eps,0));
 
   /* attempt to get dense representations of A and B separately */
@@ -157,6 +159,22 @@ static PetscErrorCode EPSSolve_LAPACK(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   EPSLAPACK - EPSLAPACK = "lapack" - A wrapper to LAPACK eigensolvers.
+
+   Notes:
+   This is not really a full-featured eigensolver but simply an interface to
+   some LAPACK routines {cite:p}`And99`. These routines operate sequentially
+   in dense mode and therefore are suitable only for small size problems.
+   This solver should be used only for debugging purposes.
+
+   The LAPACK routine is not called directly, instead a `DS` object of
+   the appropriate type is set up.
+
+   Level: beginner
+
+.seealso: [](ch:eps), `EPS`, `EPSType`, `EPSSetType()`, `DS`
+M*/
 SLEPC_EXTERN PetscErrorCode EPSCreate_LAPACK(EPS eps)
 {
   PetscFunctionBegin;
