@@ -32,7 +32,7 @@
 
 #include <slepc/private/epsimpl.h>                /*I "slepceps.h" I*/
 #include <slepcblaslapack.h>
-/* petsc headers */
+/* PETSc headers */
 #include <petscdm.h>
 #include <petscsnes.h>
 
@@ -84,6 +84,7 @@ static PetscErrorCode EPSSetUp_Power(EPS eps)
 
   PetscFunctionBegin;
   EPSCheckNotStructured(eps);
+  if (eps->nev==0) eps->nev = 1;
   if (eps->ncv!=PETSC_DETERMINE) {
     PetscCheck(eps->ncv>=eps->nev,PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"The value of ncv must be at least nev");
   } else eps->ncv = eps->nev;
@@ -101,7 +102,7 @@ static PetscErrorCode EPSSetUp_Power(EPS eps)
     PetscCall(STGetMatMode(eps->st,&mode));
     PetscCheck(mode!=ST_MATMODE_INPLACE,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"ST matrix mode inplace does not work with variable shifts");
   }
-  EPSCheckUnsupported(eps,EPS_FEATURE_BALANCE | EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_CONVERGENCE);
+  EPSCheckUnsupported(eps,EPS_FEATURE_BALANCE | EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_CONVERGENCE | EPS_FEATURE_THRESHOLD);
   EPSCheckIgnored(eps,EPS_FEATURE_EXTRACTION);
   PetscCall(EPSAllocateSolution(eps,0));
   PetscCall(EPS_SetInnerProduct(eps));
@@ -728,7 +729,7 @@ static PetscErrorCode EPSBackTransform_Power(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode EPSSetFromOptions_Power(EPS eps,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode EPSSetFromOptions_Power(EPS eps,PetscOptionItems PetscOptionsObject)
 {
   EPS_POWER         *power = (EPS_POWER*)eps->data;
   PetscBool         flg,val;
@@ -780,25 +781,26 @@ static PetscErrorCode EPSPowerSetShiftType_Power(EPS eps,EPSPowerShiftType shift
    Logically Collective
 
    Input Parameters:
-+  eps - the eigenproblem solver context
--  shift - the type of shift
++  eps - the linear eigensolver context
+-  shift - the type of shift, see `EPSPowerShiftType` for possible values
 
    Options Database Key:
-.  -eps_power_shift_type - Sets the shift type (either 'constant' or
-                           'rayleigh' or 'wilkinson')
+.  -eps_power_shift_type \<shift\> - sets the shift type, either `constant`, `rayleigh` or `wilkinson`
 
    Notes:
-   By default, shifts are constant (EPS_POWER_SHIFT_CONSTANT) and the iteration
+   By default, shifts are constant (`EPS_POWER_SHIFT_CONSTANT`) and the iteration
    is the simple power method (or inverse iteration if a shift-and-invert
    transformation is being used).
 
-   A variable shift can be specified (EPS_POWER_SHIFT_RAYLEIGH or
-   EPS_POWER_SHIFT_WILKINSON). In this case, the iteration behaves rather like
+   A variable shift can be specified (`EPS_POWER_SHIFT_RAYLEIGH` or
+   `EPS_POWER_SHIFT_WILKINSON`). In this case, the iteration behaves rather like
    a cubic converging method such as RQI.
 
+   Details of the three variants can be found in {cite:p}`Her05`.
+
    Level: advanced
 
-.seealso: EPSPowerGetShiftType(), STSetShift(), EPSPowerShiftType
+.seealso: [](ch:eps), `EPSPOWER`, `EPSPowerGetShiftType()`, `STSetShift()`, `EPSPowerShiftType`
 @*/
 PetscErrorCode EPSPowerSetShiftType(EPS eps,EPSPowerShiftType shift)
 {
@@ -825,14 +827,14 @@ static PetscErrorCode EPSPowerGetShiftType_Power(EPS eps,EPSPowerShiftType *shif
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  shift - the type of shift
 
    Level: advanced
 
-.seealso: EPSPowerSetShiftType(), EPSPowerShiftType
+.seealso: [](ch:eps), `EPSPOWER`, `EPSPowerSetShiftType()`, `EPSPowerShiftType`
 @*/
 PetscErrorCode EPSPowerGetShiftType(EPS eps,EPSPowerShiftType *shift)
 {
@@ -863,29 +865,29 @@ static PetscErrorCode EPSPowerSetNonlinear_Power(EPS eps,PetscBool nonlinear)
    Logically Collective
 
    Input Parameters:
-+  eps - the eigenproblem solver context
++  eps - the linear eigensolver context
 -  nonlinear - whether the problem is nonlinear or not
 
    Options Database Key:
-.  -eps_power_nonlinear - Sets the nonlinear flag
+.  -eps_power_nonlinear - sets the nonlinear flag
 
    Notes:
    If this flag is set, the solver assumes that the problem is nonlinear,
    that is, the operators that define the eigenproblem are not constant
-   matrices, but depend on the eigenvector, A(x)*x=lambda*B(x)*x. This is
+   matrices, but depend on the eigenvector, $A(x)x=\lambda B(x)x$. This is
    different from the case of nonlinearity with respect to the eigenvalue
-   (use the NEP solver class for this kind of problems).
+   (use the `NEP` solver class for this kind of problems).
 
    The way in which nonlinear operators are specified is very similar to
-   the case of PETSc's SNES solver. The difference is that the callback
-   functions are provided via composed functions "formFunction" and
-   "formJacobian" in each of the matrix objects passed as arguments of
-   EPSSetOperators(). The application context required for these functions
-   can be attached via a composed PetscContainer.
+   the case of PETSc's `SNES` solver. The difference is that the callback
+   functions are provided via composed functions `formFunction` and
+   `formJacobian` in each of the matrix objects passed as arguments of
+   `EPSSetOperators()`. The application context required for these functions
+   can be attached via a composed `PetscContainer`.
 
    Level: advanced
 
-.seealso: EPSPowerGetNonlinear(), EPSSetOperators()
+.seealso: [](ch:eps), `EPSPOWER`, `EPSPowerGetNonlinear()`, `EPSSetOperators()`
 @*/
 PetscErrorCode EPSPowerSetNonlinear(EPS eps,PetscBool nonlinear)
 {
@@ -911,14 +913,14 @@ static PetscErrorCode EPSPowerGetNonlinear_Power(EPS eps,PetscBool *nonlinear)
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  nonlinear - the nonlinear flag
 
    Level: advanced
 
-.seealso: EPSPowerSetUpdate(), EPSPowerSetNonlinear()
+.seealso: [](ch:eps), `EPSPOWER`, `EPSPowerSetUpdate()`, `EPSPowerSetNonlinear()`
 @*/
 PetscErrorCode EPSPowerGetNonlinear(EPS eps,PetscBool *nonlinear)
 {
@@ -947,15 +949,18 @@ static PetscErrorCode EPSPowerSetUpdate_Power(EPS eps,PetscBool update)
    Logically Collective
 
    Input Parameters:
-+  eps - the eigenproblem solver context
++  eps - the linear eigensolver context
 -  update - whether the residual is updated monolithically or not
 
    Options Database Key:
-.  -eps_power_update - Sets the update flag
+.  -eps_power_update - sets the update flag
+
+   Note:
+   This flag is relevant only in nonlinear problems, see `EPSPowerSetNonlinear()`.
 
    Level: advanced
 
-.seealso: EPSPowerGetUpdate(), EPSPowerGetNonlinear(), EPSSetOperators()
+.seealso: [](ch:eps), `EPSPOWER`, `EPSPowerGetUpdate()`, `EPSPowerGetNonlinear()`, `EPSSetOperators()`
 @*/
 PetscErrorCode EPSPowerSetUpdate(EPS eps,PetscBool update)
 {
@@ -982,14 +987,14 @@ static PetscErrorCode EPSPowerGetUpdate_Power(EPS eps,PetscBool *update)
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  update - the update flag
 
    Level: advanced
 
-.seealso: EPSPowerSetUpdate(), EPSPowerSetNonlinear()
+.seealso: [](ch:eps), `EPSPOWER`, `EPSPowerSetUpdate()`, `EPSPowerSetNonlinear()`
 @*/
 PetscErrorCode EPSPowerGetUpdate(EPS eps,PetscBool *update)
 {
@@ -1010,7 +1015,7 @@ static PetscErrorCode EPSPowerSetSignNormalization_Power(EPS eps,PetscBool sign_
 }
 
 /*@
-   EPSPowerSetSignNormalization - Sets a flag to indicate whether the Bx vector
+   EPSPowerSetSignNormalization - Sets a flag to indicate whether the $Bx$ vector
    should be normalized by the sign of the first non-zero element in the vector.
    E.g., if this is true, the post-normalization value of the first non-zero element
    in the vector is guaranteed to be positive.
@@ -1018,16 +1023,19 @@ static PetscErrorCode EPSPowerSetSignNormalization_Power(EPS eps,PetscBool sign_
    Logically Collective
 
    Input Parameters:
-+  eps - the eigenproblem solver context
--  sign_normalization - whether Bx should be multiplied by the sign of the first non-zero
++  eps                - the linear eigensolver context
+-  sign_normalization - whether $Bx$ should be multiplied by the sign of the first non-zero
                         element when performing normalization steps
 
    Options Database Key:
-.  -eps_power_sign_normalization - Sets the sign normalization flag
+.  -eps_power_sign_normalization - sets the sign normalization flag
+
+   Note:
+   This flag is relevant only in nonlinear problems, see `EPSPowerSetNonlinear()`.
 
    Level: advanced
 
-.seealso: EPSPowerGetSignNormalization()
+.seealso: [](ch:eps), `EPSPOWER`, `EPSPowerSetNonlinear()`, `EPSPowerGetSignNormalization()`
 @*/
 PetscErrorCode EPSPowerSetSignNormalization(EPS eps,PetscBool sign_normalization)
 {
@@ -1048,7 +1056,7 @@ static PetscErrorCode EPSPowerGetSignNormalization_Power(EPS eps,PetscBool *sign
 }
 
 /*@
-   EPSPowerGetSignNormalization - Returns a flag indicating whether the Bx vector
+   EPSPowerGetSignNormalization - Returns a flag indicating whether the $Bx$ vector
    is normalized by the sign of the first non-zero element in the vector. E.g.,
    if this is true, the post-normalization value of the first non-zero element in
    the vector is guaranteed to be positive.
@@ -1056,14 +1064,14 @@ static PetscErrorCode EPSPowerGetSignNormalization_Power(EPS eps,PetscBool *sign
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  sign_normalization - the sign normalization flag
 
    Level: advanced
 
-.seealso: EPSPowerSetSignNormalization()
+.seealso: [](ch:eps), `EPSPOWER`, `EPSPowerSetSignNormalization()`
 @*/
 PetscErrorCode EPSPowerGetSignNormalization(EPS eps,PetscBool *sign_normalization)
 {
@@ -1087,18 +1095,21 @@ static PetscErrorCode EPSPowerSetSNES_Power(EPS eps,SNES snes)
 }
 
 /*@
-   EPSPowerSetSNES - Associate a nonlinear solver object (SNES) to the
+   EPSPowerSetSNES - Associate a nonlinear solver object (`SNES`) to the
    eigenvalue solver (to be used in nonlinear inverse iteration).
 
    Collective
 
    Input Parameters:
-+  eps  - the eigenvalue solver
++  eps  - the linear eigensolver context
 -  snes - the nonlinear solver object
 
+   Note:
+   This flag is relevant only in nonlinear problems, see `EPSPowerSetNonlinear()`.
+
    Level: advanced
 
-.seealso: EPSPowerGetSNES()
+.seealso: [](ch:eps), `EPSPOWER`, `EPSPowerSetNonlinear()`, `EPSPowerGetSNES()`
 @*/
 PetscErrorCode EPSPowerSetSNES(EPS eps,SNES snes)
 {
@@ -1127,20 +1138,20 @@ static PetscErrorCode EPSPowerGetSNES_Power(EPS eps,SNES *snes)
 }
 
 /*@
-   EPSPowerGetSNES - Retrieve the nonlinear solver object (SNES) associated
+   EPSPowerGetSNES - Retrieve the nonlinear solver object (`SNES`) associated
    with the eigenvalue solver.
 
    Not Collective
 
    Input Parameter:
-.  eps - the eigenvalue solver
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  snes - the nonlinear solver object
 
    Level: advanced
 
-.seealso: EPSPowerSetSNES()
+.seealso: [](ch:eps), `EPSPOWER`, `EPSPowerSetSNES()`
 @*/
 PetscErrorCode EPSPowerGetSNES(EPS eps,SNES *snes)
 {
@@ -1235,6 +1246,33 @@ static PetscErrorCode EPSSetDefaultST_Power(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   EPSPOWER - EPSPOWER = "power" - The simple power iteration and inverse
+   iteration.
+
+   Notes:
+   This solver is very basic and is not recommended in general, since it
+   will not be competitive with respect to other solvers.
+
+   The implemented method is the power iteration, or inverse iteration in
+   case the selected spectral transformation is `STSINVERT`. In this latter
+   case it is possible to use a dynamic shift, as in the RQI method, see
+   `EPSPowerSetShiftType()`.
+
+   The solver incorporates deflation so that several eigenpairs can be
+   computed. There is also a two-sided implementation that also computes
+   left eigenvectors.
+
+   This solver can also be used for nonlinear inverse iteration on the problem
+   $A(x)x=\lambda B(x)x$, where $A$ and $B$ are not constant matrices but
+   depend on the eigenvector $x$. This mode is enabled with `EPSPowerSetNonlinear()`.
+   Note that this is a nonlinear eigenvector problem, as opposed to problems
+   addressed in `NEP` that are nonlinear with respect to the eigenvalue.
+
+   Level: beginner
+
+.seealso: [](ch:eps), `EPS`, `EPSType`, `EPSSetType()`, `EPSSetTwoSided()`, `EPSPowerSetShiftType()`, `EPSPowerSetNonlinear()`
+M*/
 SLEPC_EXTERN PetscErrorCode EPSCreate_Power(EPS eps)
 {
   EPS_POWER      *ctx;
