@@ -51,13 +51,13 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_ChASE(EPS);
 #endif
 
 /*@C
-  EPSRegisterAll - Registers all the eigenvalue solvers in the EPS package.
+  EPSRegisterAll - Registers all the eigenvalue solvers in the `EPS` package.
 
   Not Collective
 
   Level: advanced
 
-.seealso: EPSRegister()
+.seealso: [](ch:eps), `EPSRegister()`
 @*/
 PetscErrorCode EPSRegisterAll(void)
 {
@@ -107,13 +107,13 @@ PetscErrorCode EPSRegisterAll(void)
 }
 
 /*@C
-  EPSMonitorRegisterAll - Registers all the monitors in the EPS package.
+  EPSMonitorRegisterAll - Registers all the monitors in the `EPS` package.
 
   Not Collective
 
   Level: advanced
 
-.seealso: EPSMonitorRegister()
+.seealso: [](ch:eps), `EPSMonitorRegister()`
 @*/
 PetscErrorCode EPSMonitorRegisterAll(void)
 {
