@@ -8,7 +8,7 @@
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-static char help[] = "Block-diagonal orthogonal eigenproblem.\n"
+static char help[] = "Block-diagonal orthogonal eigenproblem.\n\n"
   "The command line options are:\n"
   "  -n <n>, where <n> = matrix dimension.\n"
   "  -seed <s>, where <s> = seed for random number generation.\n\n";
@@ -25,7 +25,7 @@ int main(int argc,char **argv)
   PetscMPIInt    rank;
 
   PetscFunctionBeginUser;
-  PetscCall(SlepcInitialize(&argc,&argv,(char*)0,help));
+  PetscCall(SlepcInitialize(&argc,&argv,NULL,help));
   PetscCallMPI(MPI_Comm_rank(PETSC_COMM_WORLD,&rank));
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-n",&n,NULL));
   PetscCall(PetscPrintf(PETSC_COMM_WORLD,"\nOrthogonal eigenproblem, n=%" PetscInt_FMT "\n\n",n));
