@@ -8,7 +8,7 @@
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-static char help[] = "Illustrates the use of shell spectral transformations. "
+static char help[] = "Illustrates the use of shell spectral transformations.\n\n"
   "The problem to be solved is the same as ex1.c and"
   "corresponds to the Laplacian operator in 1 dimension.\n\n"
   "The command line options are:\n"
@@ -44,7 +44,7 @@ int main (int argc,char **argv)
   PetscBool      set_ht=PETSC_FALSE;
 
   PetscFunctionBeginUser;
-  PetscCall(SlepcInitialize(&argc,&argv,(char*)0,help));
+  PetscCall(SlepcInitialize(&argc,&argv,NULL,help));
 
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-n",&n,NULL));
   PetscCall(PetscPrintf(PETSC_COMM_WORLD,"\n1-D Laplacian Eigenproblem (shell-enabled), n=%" PetscInt_FMT "\n\n",n));
