@@ -62,7 +62,7 @@ int main(int argc,char **argv)
   PetscBool      use_shell_matrix=PETSC_FALSE,test_init_sol=PETSC_FALSE,use_custom_norm=PETSC_FALSE,sign_normalization=PETSC_TRUE;
 
   PetscFunctionBeginUser;
-  PetscCall(SlepcInitialize(&argc,&argv,(char*)0,help));
+  PetscCall(SlepcInitialize(&argc,&argv,NULL,help));
   comm = PETSC_COMM_WORLD;
   /* Create a quadrilateral mesh on domain (0,1)x(0,1) */
   PetscCall(CreateSquareMesh(comm,&dm));
@@ -76,9 +76,9 @@ int main(int argc,char **argv)
     PetscCall(MatGetLocalSize(P,&m,&n));
     PetscCall(MatGetSize(P,&M,&N));
     PetscCall(MatCreateShell(comm,m,n,M,N,&user,&A));
-    PetscCall(MatShellSetOperation(A,MATOP_MULT,(void(*)(void))MatMult_A));
+    PetscCall(MatShellSetOperation(A,MATOP_MULT,(PetscErrorCodeFn*)MatMult_A));
     PetscCall(MatCreateShell(comm,m,n,M,N,&user,&B));
-    PetscCall(MatShellSetOperation(B,MATOP_MULT,(void(*)(void))MatMult_B));
+    PetscCall(MatShellSetOperation(B,MATOP_MULT,(PetscErrorCodeFn*)MatMult_B));
   } else {
     PetscCall(DMCreateMatrix(dm,&A));
     PetscCall(MatDuplicate(A,MAT_COPY_VALUES,&B));
@@ -155,7 +155,7 @@ int main(int argc,char **argv)
     PetscCall(SNESGetFunctionNorm(snes,&norm0));
     /* Make the tolerance smaller than the last residual
        SNES will converge right away if the initial is setup correctly */
-    PetscCall(SNESSetTolerances(snes,norm0*1.2,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT));
+    PetscCall(SNESSetTolerances(snes,norm0*1.2,PETSC_CURRENT,PETSC_CURRENT,PETSC_CURRENT,PETSC_CURRENT));
     PetscCall(EPSSolve(eps));
     /* Number of Newton iterations supposes to be zero */
     PetscCall(SNESGetIterationNumber(snes,&nits));
@@ -277,7 +277,7 @@ PetscErrorCode CreateSquareMesh(MPI_Comm comm,DM *dm)
   PetscMPIInt    size;
 
   PetscFunctionBegin;
-  PetscCall(DMPlexCreateBoxMesh(comm,dim,PETSC_FALSE,cells,NULL,NULL,NULL,PETSC_TRUE,dm));
+  PetscCall(DMPlexCreateBoxMesh(comm,dim,PETSC_FALSE,cells,NULL,NULL,NULL,PETSC_TRUE,0,PETSC_TRUE,dm));
   PetscCall(DMSetFromOptions(*dm));
   PetscCall(DMSetUp(*dm));
   PetscCallMPI(MPI_Comm_size(comm,&size));
@@ -388,7 +388,7 @@ PetscErrorCode FormFunctionAB(SNES snes,Vec x,Vec Ax,Vec Bx,void *ctx)
   PetscFunctionBegin;
   /*
    * In real applications, users should have a generic formFunctionAB which
-   * forms Ax and Bx simultaneously for an more efficient calculation.
+   * forms Ax and Bx simultaneously for a more efficient calculation.
    * In this example, we just call FormFunctionA+FormFunctionB to mimic how
    * to use FormFunctionAB
    */
@@ -566,7 +566,7 @@ PetscErrorCode MatMult_B(Mat B,Vec x,Vec y)
       test:
          suffix: 11
          requires: complex
-         args: -use_custom_norm {{0 1}} -sign_normalization 0 -eps_power_snes_type nrichardson -eps_power_snes_atol 1e-12
+         args: -use_custom_norm {{0 1}} -sign_normalization 0 -eps_power_snes_type nrichardson -eps_power_snes_atol 1e-12 -eps_power_snes_linesearch_atol 1e-22
       test:
          suffix: 12
          requires: complex
