@@ -18,11 +18,11 @@ const char *const*LMEConvergedReasons = LMEConvergedReasons_Shifted + 2;
 
 /*@C
   LMEFinalizePackage - This function destroys everything in the SLEPc interface
-  to the LME package. It is called from SlepcFinalize().
+  to the `LME` package. It is called from `SlepcFinalize()`.
 
   Level: developer
 
-.seealso: SlepcFinalize()
+.seealso: [](ch:lme), `SlepcFinalize()`, `LMEInitializePackage()`
 @*/
 PetscErrorCode LMEFinalizePackage(void)
 {
@@ -34,17 +34,20 @@ PetscErrorCode LMEFinalizePackage(void)
   LMEPackageInitialized       = PETSC_FALSE;
   LMERegisterAllCalled        = PETSC_FALSE;
   LMEMonitorRegisterAllCalled = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  LMEInitializePackage - This function initializes everything in the LME package.
-  It is called from PetscDLLibraryRegister() when using dynamic libraries, and
-  on the first call to LMECreate() when using static libraries.
+   LMEInitializePackage - This function initializes everything in the `LME` package.
+   It is called from `PetscDLLibraryRegister_slepclme()` when using dynamic libraries, and
+   on the first call to `LMECreate()` when using shared or static libraries.
 
-  Level: developer
+   Note:
+   This function never needs to be called by SLEPc users.
 
-.seealso: SlepcInitialize()
+   Level: developer
+
+.seealso: [](ch:lme), `LME`, `SlepcInitialize()`, `LMEFinalizePackage()`
 @*/
 PetscErrorCode LMEInitializePackage(void)
 {
@@ -53,7 +56,7 @@ PetscErrorCode LMEInitializePackage(void)
   PetscClassId   classids[1];
 
   PetscFunctionBegin;
-  if (LMEPackageInitialized) PetscFunctionReturn(0);
+  if (LMEPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   LMEPackageInitialized = PETSC_TRUE;
   /* Register Classes */
   PetscCall(PetscClassIdRegister("Lin. Matrix Equation",&LME_CLASSID));
@@ -76,7 +79,7 @@ PetscErrorCode LMEInitializePackage(void)
   }
   /* Register package finalizer */
   PetscCall(PetscRegisterFinalize(LMEFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_HAVE_DYNAMIC_LIBRARIES)
@@ -91,6 +94,6 @@ SLEPC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepclme(void)
 {
   PetscFunctionBegin;
   PetscCall(LMEInitializePackage());
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif /* PETSC_HAVE_DYNAMIC_LIBRARIES */
