@@ -28,7 +28,7 @@ PetscFunctionList MFNMonitorDestroyList       = NULL;
 PetscBool         MFNMonitorRegisterAllCalled = PETSC_FALSE;
 
 /*@
-   MFNView - Prints the MFN data structure.
+   MFNView - Prints the `MFN` data structure.
 
    Collective
 
@@ -37,22 +37,21 @@ PetscBool         MFNMonitorRegisterAllCalled = PETSC_FALSE;
 -  viewer - optional visualization context
 
    Options Database Key:
-.  -mfn_view -  Calls MFNView() at end of MFNSolve()
+.  -mfn_view - calls `MFNView()` at end of `MFNSolve()`
 
-   Note:
+   Notes:
    The available visualization contexts include
-+     PETSC_VIEWER_STDOUT_SELF - standard output (default)
--     PETSC_VIEWER_STDOUT_WORLD - synchronized standard
-         output where only the first processor opens
-         the file.  All other processors send their
-         data to the first processor to print.
++     `PETSC_VIEWER_STDOUT_SELF` - standard output (default)
+-     `PETSC_VIEWER_STDOUT_WORLD` - synchronized standard output where only the
+         first process opens the file; all other processes send their data to the
+         first one to print
 
-   The user can open an alternative visualization context with
-   PetscViewerASCIIOpen() - output to a specified file.
+   The user can open an alternative visualization context with `PetscViewerASCIIOpen()`
+   to output to a specified file.
 
    Level: beginner
 
-.seealso: MFNCreate()
+.seealso: [](ch:mfn), `MFNCreate()`, `MFNViewFromOptions()`
 @*/
 PetscErrorCode MFNView(MFN mfn,PetscViewer viewer)
 {
@@ -84,18 +83,18 @@ PetscErrorCode MFNView(MFN mfn,PetscViewer viewer)
 }
 
 /*@
-   MFNViewFromOptions - View from options
+   MFNViewFromOptions - View (print) an `MFN` object based on values in the options database.
 
    Collective
 
    Input Parameters:
-+  mfn  - the matrix function context
-.  obj  - optional object
++  mfn  - the matrix function solver context
+.  obj  - optional object that provides the options prefix used to query the options database
 -  name - command line option
 
    Level: intermediate
 
-.seealso: MFNView(), MFNCreate()
+.seealso: [](ch:mfn), `MFNView()`, `MFNCreate()`, `PetscObjectViewFromOptions()`
 @*/
 PetscErrorCode MFNViewFromOptions(MFN mfn,PetscObject obj,const char name[])
 {
@@ -105,26 +104,29 @@ PetscErrorCode MFNViewFromOptions(MFN mfn,PetscObject obj,const char name[])
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 /*@
-   MFNConvergedReasonView - Displays the reason an MFN solve converged or diverged.
+   MFNConvergedReasonView - Displays the reason an `MFN` solve converged or diverged.
 
    Collective
 
    Input Parameters:
-+  mfn - the matrix function context
++  mfn - the matrix function solver context
 -  viewer - the viewer to display the reason
 
-   Options Database Keys:
-.  -mfn_converged_reason - print reason for convergence, and number of iterations
+   Options Database Key:
+.  -mfn_converged_reason - print reason for convergence/divergence, and number of iterations
 
-   Note:
-   To change the format of the output call PetscViewerPushFormat(viewer,format) before
-   this call. Use PETSC_VIEWER_DEFAULT for the default, use PETSC_VIEWER_FAILED to only
+   Notes:
+   Use `MFNConvergedReasonViewFromOptions()` to display the reason based on values
+   in the options database.
+
+   To change the format of the output call `PetscViewerPushFormat()` before this
+   call. Use `PETSC_VIEWER_DEFAULT` for the default, or `PETSC_VIEWER_FAILED` to only
    display a reason if it fails. The latter can be set in the command line with
-   -mfn_converged_reason ::failed
+   `-mfn_converged_reason ::failed`.
 
    Level: intermediate
 
-.seealso: MFNSetTolerances(), MFNGetIterationNumber(), MFNConvergedReasonViewFromOptions()
+.seealso: [](ch:mfn), `MFNSetTolerances()`, `MFNGetIterationNumber()`, `MFNConvergedReasonViewFromOptions()`
 @*/
 PetscErrorCode MFNConvergedReasonView(MFN mfn,PetscViewer viewer)
 {
@@ -146,16 +148,16 @@ PetscErrorCode MFNConvergedReasonView(MFN mfn,PetscViewer viewer)
 
 /*@
    MFNConvergedReasonViewFromOptions - Processes command line options to determine if/how
-   the MFN converged reason is to be viewed.
+   the `MFN` converged reason is to be viewed.
 
    Collective
 
    Input Parameter:
-.  mfn - the matrix function context
+.  mfn - the matrix function solver context
 
-   Level: developer
+   Level: intermediate
 
-.seealso: MFNConvergedReasonView()
+.seealso: [](ch:mfn), `MFNConvergedReasonView()`
 @*/
 PetscErrorCode MFNConvergedReasonViewFromOptions(MFN mfn)
 {
@@ -179,7 +181,7 @@ PetscErrorCode MFNConvergedReasonViewFromOptions(MFN mfn)
 }
 
 /*@
-   MFNCreate - Creates the default MFN context.
+   MFNCreate - Creates the `MFN` context.
 
    Collective
 
@@ -187,14 +189,14 @@ PetscErrorCode MFNConvergedReasonViewFromOptions(MFN mfn)
 .  comm - MPI communicator
 
    Output Parameter:
-.  outmfn - location to put the MFN context
+.  outmfn - location to put the `MFN` context
 
    Note:
-   The default MFN type is MFNKRYLOV
+   The default `MFN` type is `MFNKRYLOV`.
 
    Level: beginner
 
-.seealso: MFNSetUp(), MFNSolve(), MFNDestroy(), MFN
+.seealso: [](ch:mfn), `MFNSetUp()`, `MFNSolve()`, `MFNDestroy()`, `MFN`
 @*/
 PetscErrorCode MFNCreate(MPI_Comm comm,MFN *outmfn)
 {
@@ -230,33 +232,31 @@ PetscErrorCode MFNCreate(MPI_Comm comm,MFN *outmfn)
 }
 
 /*@
-   MFNSetType - Selects the particular solver to be used in the MFN object.
+   MFNSetType - Selects the particular solver to be used in the `MFN` object.
 
    Logically Collective
 
    Input Parameters:
-+  mfn  - the matrix function context
++  mfn  - the matrix function solver context
 -  type - a known method
 
    Options Database Key:
-.  -mfn_type <method> - Sets the method; use -help for a list
-    of available methods
+.  -mfn_type \<type\> - sets the method; use `-help` for a list of available methods
 
    Notes:
-   See "slepc/include/slepcmfn.h" for available methods. The default
-   is MFNKRYLOV
+   See `MFNType` for available methods. The default is `MFNKRYLOV`.
 
-   Normally, it is best to use the MFNSetFromOptions() command and
-   then set the MFN type from the options database rather than by using
+   Normally, it is best to use the `MFNSetFromOptions()` command and
+   then set the `MFN` type from the options database rather than by using
    this routine.  Using the options database provides the user with
    maximum flexibility in evaluating the different available methods.
-   The MFNSetType() routine is provided for those situations where it
+   The `MFNSetType()` routine is provided for those situations where it
    is necessary to set the iterative solver independently of the command
    line or options database.
 
    Level: intermediate
 
-.seealso: MFNType
+.seealso: [](ch:mfn), `MFNType`
 @*/
 PetscErrorCode MFNSetType(MFN mfn,MFNType type)
 {
@@ -283,19 +283,19 @@ PetscErrorCode MFNSetType(MFN mfn,MFNType type)
 }
 
 /*@
-   MFNGetType - Gets the MFN type as a string from the MFN object.
+   MFNGetType - Gets the `MFN` type as a string from the `MFN` object.
 
    Not Collective
 
    Input Parameter:
-.  mfn - the matrix function context
+.  mfn - the matrix function solver context
 
    Output Parameter:
-.  type - name of MFN method
+.  type - name of `MFN` method
 
    Level: intermediate
 
-.seealso: MFNSetType()
+.seealso: [](ch:mfn), `MFNSetType()`
 @*/
 PetscErrorCode MFNGetType(MFN mfn,MFNType *type)
 {
@@ -315,22 +315,23 @@ PetscErrorCode MFNGetType(MFN mfn,MFNType *type)
 +  name - name of a new user-defined solver
 -  function - routine to create the solver context
 
-   Notes:
-   MFNRegister() may be called multiple times to add several user-defined solvers.
+   Note:
+   `MFNRegister()` may be called multiple times to add several user-defined solvers.
 
    Example Usage:
 .vb
-    MFNRegister("my_solver",MySolverCreate);
+   MFNRegister("my_solver",MySolverCreate);
 .ve
 
    Then, your solver can be chosen with the procedural interface via
-$     MFNSetType(mfn,"my_solver")
-   or at runtime via the option
-$     -mfn_type my_solver
+.vb
+   MFNSetType(mfn,"my_solver")
+.ve
+   or at runtime via the option `-mfn_type my_solver`.
 
    Level: advanced
 
-.seealso: MFNRegisterAll()
+.seealso: [](ch:mfn), `MFNRegisterAll()`
 @*/
 PetscErrorCode MFNRegister(const char *name,PetscErrorCode (*function)(MFN))
 {
@@ -341,24 +342,25 @@ PetscErrorCode MFNRegister(const char *name,PetscErrorCode (*function)(MFN))
 }
 
 /*@C
-   MFNMonitorRegister - Registers an MFN monitor routine that may be accessed with MFNMonitorSetFromOptions().
+   MFNMonitorRegister - Registers an `MFN` monitor routine that may be accessed with
+   `MFNMonitorSetFromOptions()`.
 
    Not Collective
 
    Input Parameters:
 +  name    - name of a new monitor routine
-.  vtype   - a PetscViewerType for the output
-.  format  - a PetscViewerFormat for the output
-.  monitor - monitor routine, see MFNMonitorRegisterFn
-.  create  - creation routine, or NULL
--  destroy - destruction routine, or NULL
+.  vtype   - a `PetscViewerType` for the output
+.  format  - a `PetscViewerFormat` for the output
+.  monitor - monitor routine, see `MFNMonitorRegisterFn`
+.  create  - creation routine, or `NULL`
+-  destroy - destruction routine, or `NULL`
 
    Notes:
-   MFNMonitorRegister() may be called multiple times to add several user-defined monitors.
+   `MFNMonitorRegister()` may be called multiple times to add several user-defined monitors.
 
-   The calling sequence for the given function matches the calling sequence of MFNMonitorFn
-   functions passed to MFNMonitorSet() with the additional requirement that its final argument
-   be a PetscViewerAndFormat.
+   The calling sequence for the given function matches the calling sequence of `MFNMonitorFn`
+   functions passed to `MFNMonitorSet()` with the additional requirement that its final argument
+   be a `PetscViewerAndFormat`.
 
    Example Usage:
 .vb
@@ -366,13 +368,14 @@ PetscErrorCode MFNRegister(const char *name,PetscErrorCode (*function)(MFN))
 .ve
 
    Then, your monitor can be chosen with the procedural interface via
-$      MFNMonitorSetFromOptions(mfn,"-mfn_monitor_my_monitor","my_monitor",NULL)
-   or at runtime via the option
-$      -mfn_monitor_my_monitor
+.vb
+   MFNMonitorSetFromOptions(mfn,"-mfn_monitor_my_monitor","my_monitor",NULL);
+.ve
+   or at runtime via the option `-mfn_monitor_my_monitor`.
 
    Level: advanced
 
-.seealso: MFNMonitorSet(), MFNMonitorRegisterAll()
+.seealso: [](ch:mfn), `MFNMonitorSet()`, `MFNMonitorRegisterAll()`, `MFNMonitorSetFromOptions()`
 @*/
 PetscErrorCode MFNMonitorRegister(const char name[],PetscViewerType vtype,PetscViewerFormat format,MFNMonitorRegisterFn *monitor,MFNMonitorRegisterCreateFn *create,MFNMonitorRegisterDestroyFn *destroy)
 {
@@ -388,17 +391,17 @@ PetscErrorCode MFNMonitorRegister(const char name[],PetscViewerType vtype,PetscV
 }
 
 /*@
-   MFNReset - Resets the MFN context to the initial state (prior to setup)
-   and destroys any allocated Vecs and Mats.
+   MFNReset - Resets the `MFN` context to the initial state (prior to setup)
+   and destroys any allocated `Vec`s and `Mat`s.
 
    Collective
 
    Input Parameter:
-.  mfn - matrix function context obtained from MFNCreate()
+.  mfn - the matrix function solver context
 
    Level: advanced
 
-.seealso: MFNDestroy()
+.seealso: [](ch:mfn), `MFNDestroy()`
 @*/
 PetscErrorCode MFNReset(MFN mfn)
 {
@@ -415,16 +418,16 @@ PetscErrorCode MFNReset(MFN mfn)
 }
 
 /*@
-   MFNDestroy - Destroys the MFN context.
+   MFNDestroy - Destroys the `MFN` context.
 
    Collective
 
    Input Parameter:
-.  mfn - matrix function context obtained from MFNCreate()
+.  mfn - the matrix function solver context
 
    Level: beginner
 
-.seealso: MFNCreate(), MFNSetUp(), MFNSolve()
+.seealso: [](ch:mfn), `MFNCreate()`, `MFNSetUp()`, `MFNSolve()`
 @*/
 PetscErrorCode MFNDestroy(MFN *mfn)
 {
@@ -447,16 +450,16 @@ PetscErrorCode MFNDestroy(MFN *mfn)
    Collective
 
    Input Parameters:
-+  mfn - matrix function context obtained from MFNCreate()
++  mfn - the matrix function solver context
 -  bv  - the basis vectors object
 
    Note:
-   Use MFNGetBV() to retrieve the basis vectors context (for example,
+   Use `MFNGetBV()` to retrieve the basis vectors context (for example,
    to free it at the end of the computations).
 
    Level: advanced
 
-.seealso: MFNGetBV()
+.seealso: [](ch:mfn), `MFNGetBV()`
 @*/
 PetscErrorCode MFNSetBV(MFN mfn,BV bv)
 {
@@ -476,15 +479,15 @@ PetscErrorCode MFNSetBV(MFN mfn,BV bv)
 
    Not Collective
 
-   Input Parameters:
-.  mfn - matrix function context obtained from MFNCreate()
+   Input Parameter:
+.  mfn - the matrix function solver context
 
    Output Parameter:
 .  bv - basis vectors context
 
    Level: advanced
 
-.seealso: MFNSetBV()
+.seealso: [](ch:mfn), `MFNSetBV()`
 @*/
 PetscErrorCode MFNGetBV(MFN mfn,BV *bv)
 {
@@ -506,16 +509,19 @@ PetscErrorCode MFNGetBV(MFN mfn,BV *bv)
    Collective
 
    Input Parameters:
-+  mfn - matrix function context obtained from MFNCreate()
++  mfn - the matrix function solver context
 -  fn  - the math function object
 
-   Note:
-   Use MFNGetFN() to retrieve the math function context (for example,
-   to free it at the end of the computations).
+   Notes:
+   At a later time, use `MFNGetFN()` to retrieve the math function context
+   (for example, to free it at the end of the computations).
+
+   This function is not called in normal usage. Instead, it is easier to
+   extract the internal `FN` object with `MFNGetFN()` and modify it.
 
    Level: beginner
 
-.seealso: MFNGetFN()
+.seealso: [](ch:mfn), `MFNGetFN()`
 @*/
 PetscErrorCode MFNSetFN(MFN mfn,FN fn)
 {
@@ -530,19 +536,23 @@ PetscErrorCode MFNSetFN(MFN mfn,FN fn)
 }
 
 /*@
-   MFNGetFN - Obtain the math function object associated to the MFN object.
+   MFNGetFN - Obtain the math function object associated to the `MFN` object.
 
    Not Collective
 
-   Input Parameters:
-.  mfn - matrix function context obtained from MFNCreate()
+   Input Parameter:
+.  mfn - the matrix function solver context
 
    Output Parameter:
 .  fn - math function context
 
+   Note:
+   This is the usual way to specify the function that needs to be applied
+   to a given vector in `MFNSolve()`.
+
    Level: beginner
 
-.seealso: MFNSetFN()
+.seealso: [](ch:mfn), `MFNSetFN()`. `MFNSolve()`
 @*/
 PetscErrorCode MFNGetFN(MFN mfn,FN *fn)
 {
