@@ -45,7 +45,7 @@ static PetscErrorCode NEPSetUp_Interpol(NEP nep)
   PetscFunctionBegin;
   PetscCall(NEPSetDimensions_Default(nep,nep->nev,&nep->ncv,&nep->mpd));
   PetscCheck(nep->ncv<=nep->nev+nep->mpd,PetscObjectComm((PetscObject)nep),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
-  if (nep->max_it==PETSC_DEFAULT) nep->max_it = PetscMax(5000,2*nep->n/nep->ncv);
+  if (nep->max_it==PETSC_DETERMINE) nep->max_it = PetscMax(5000,2*nep->n/nep->ncv);
   if (!nep->which) nep->which = NEP_TARGET_MAGNITUDE;
   PetscCheck(nep->which==NEP_TARGET_MAGNITUDE,PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"This solver supports only target magnitude eigenvalues");
   NEPCheckUnsupported(nep,NEP_FEATURE_CALLBACK | NEP_FEATURE_STOPPING | NEP_FEATURE_TWOSIDED);
@@ -61,9 +61,9 @@ static PetscErrorCode NEPSetUp_Interpol(NEP nep)
   }
   PetscCall(PEPSetDimensions(ctx->pep,nep->nev,nep->ncv,nep->mpd));
   PetscCall(PEPGetTolerances(ctx->pep,&tol,&its));
-  if (tol==(PetscReal)PETSC_DEFAULT) tol = SlepcDefaultTol(nep->tol);
-  if (ctx->tol==(PetscReal)PETSC_DEFAULT) ctx->tol = tol;
-  if (its==PETSC_DEFAULT) its = nep->max_it;
+  if (tol==(PetscReal)PETSC_DETERMINE) tol = SlepcDefaultTol(nep->tol);
+  if (ctx->tol==(PetscReal)PETSC_DETERMINE) ctx->tol = tol;
+  if (its==PETSC_DETERMINE) its = nep->max_it;
   PetscCall(PEPSetTolerances(ctx->pep,tol,its));
   PetscCall(NEPGetTrackAll(nep,&trackall));
   PetscCall(PEPSetTrackAll(ctx->pep,trackall));
@@ -226,7 +226,7 @@ static PetscErrorCode PEPMonitor_Interpol(PEP pep,PetscInt its,PetscInt nconv,Pe
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode NEPSetFromOptions_Interpol(NEP nep,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode NEPSetFromOptions_Interpol(NEP nep,PetscOptionItems PetscOptionsObject)
 {
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
   PetscInt       i;
@@ -237,7 +237,7 @@ static PetscErrorCode NEPSetFromOptions_Interpol(NEP nep,PetscOptionItems *Petsc
   PetscOptionsHeadBegin(PetscOptionsObject,"NEP Interpol Options");
 
     PetscCall(NEPInterpolGetInterpolation(nep,&r,&i));
-    if (!i) i = PETSC_DEFAULT;
+    if (!i) i = PETSC_DETERMINE;
     PetscCall(PetscOptionsInt("-nep_interpol_interpolation_degree","Maximum degree of polynomial interpolation","NEPInterpolSetInterpolation",i,&i,&flg1));
     PetscCall(PetscOptionsReal("-nep_interpol_interpolation_tol","Tolerance for interpolation coefficients","NEPInterpolSetInterpolation",r,&r,&flg2));
     if (flg1 || flg2) PetscCall(NEPInterpolSetInterpolation(nep,r,i));
@@ -254,18 +254,18 @@ static PetscErrorCode NEPInterpolSetInterpolation_Interpol(NEP nep,PetscReal tol
   NEP_INTERPOL   *ctx = (NEP_INTERPOL*)nep->data;
 
   PetscFunctionBegin;
-  if (tol == (PetscReal)PETSC_DEFAULT) {
-    ctx->tol   = PETSC_DEFAULT;
+  if (tol == (PetscReal)PETSC_DETERMINE) {
+    ctx->tol   = PETSC_DETERMINE;
     nep->state = NEP_STATE_INITIAL;
-  } else {
+  } else if (tol != (PetscReal)PETSC_CURRENT) {
     PetscCheck(tol>0.0,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of tol. Must be > 0");
     ctx->tol = tol;
   }
-  if (degree == PETSC_DEFAULT || degree == PETSC_DECIDE) {
+  if (degree == PETSC_DETERMINE) {
     ctx->maxdeg = 0;
     if (nep->state) PetscCall(NEPReset(nep));
     nep->state = NEP_STATE_INITIAL;
-  } else {
+  } else if (degree != PETSC_CURRENT) {
     PetscCheck(degree>0,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of degree. Must be > 0");
     if (ctx->maxdeg != degree) {
       ctx->maxdeg = degree;
@@ -283,20 +283,21 @@ static PetscErrorCode NEPInterpolSetInterpolation_Interpol(NEP nep,PetscReal tol
    Collective
 
    Input Parameters:
-+  nep - nonlinear eigenvalue solver
++  nep - the nonlinear eigensolver context
 .  tol - tolerance to stop computing polynomial coefficients
 -  deg - maximum degree of interpolation
 
-   Options Database Key:
-+  -nep_interpol_interpolation_tol <tol> - Sets the tolerance to stop computing polynomial coefficients
--  -nep_interpol_interpolation_degree <degree> - Sets the maximum degree of interpolation
+   Options Database Keys:
++  -nep_interpol_interpolation_tol \<tol\>    - sets the tolerance to stop computing polynomial coefficients
+-  -nep_interpol_interpolation_degree \<deg\> - sets the maximum degree of interpolation
 
-   Notes:
-   Use PETSC_DEFAULT for either argument to assign a reasonably good value.
+   Note:
+   `PETSC_CURRENT` can be used to preserve the current value of any of the
+   arguments, and `PETSC_DETERMINE` to set them to a default value.
 
    Level: advanced
 
-.seealso: NEPInterpolGetInterpolation()
+.seealso: [](ch:nep), `NEPINTERPOL`, `NEPInterpolGetInterpolation()`
 @*/
 PetscErrorCode NEPInterpolSetInterpolation(NEP nep,PetscReal tol,PetscInt deg)
 {
@@ -325,7 +326,7 @@ static PetscErrorCode NEPInterpolGetInterpolation_Interpol(NEP nep,PetscReal *to
    Not Collective
 
    Input Parameter:
-.  nep - nonlinear eigenvalue solver
+.  nep - the nonlinear eigensolver context
 
    Output Parameters:
 +  tol - tolerance to stop computing polynomial coefficients
@@ -333,7 +334,7 @@ static PetscErrorCode NEPInterpolGetInterpolation_Interpol(NEP nep,PetscReal *to
 
    Level: advanced
 
-.seealso: NEPInterpolSetInterpolation()
+.seealso: [](ch:nep), `NEPINTERPOL`, `NEPInterpolSetInterpolation()`
 @*/
 PetscErrorCode NEPInterpolGetInterpolation(NEP nep,PetscReal *tol,PetscInt *deg)
 {
@@ -356,18 +357,18 @@ static PetscErrorCode NEPInterpolSetPEP_Interpol(NEP nep,PEP pep)
 }
 
 /*@
-   NEPInterpolSetPEP - Associate a polynomial eigensolver object (PEP) to the
+   NEPInterpolSetPEP - Associate a polynomial eigensolver object (`PEP`) to the
    nonlinear eigenvalue solver.
 
    Collective
 
    Input Parameters:
-+  nep - nonlinear eigenvalue solver
--  pep - the polynomial eigensolver object
++  nep - the nonlinear eigensolver context
+-  pep - the polynomial eigensolver context
 
    Level: advanced
 
-.seealso: NEPInterpolGetPEP()
+.seealso: [](ch:nep), `NEPINTERPOL`, `NEPInterpolGetPEP()`
 @*/
 PetscErrorCode NEPInterpolSetPEP(NEP nep,PEP pep)
 {
@@ -397,20 +398,20 @@ static PetscErrorCode NEPInterpolGetPEP_Interpol(NEP nep,PEP *pep)
 }
 
 /*@
-   NEPInterpolGetPEP - Retrieve the polynomial eigensolver object (PEP)
+   NEPInterpolGetPEP - Retrieve the polynomial eigensolver object (`PEP`)
    associated with the nonlinear eigenvalue solver.
 
    Collective
 
    Input Parameter:
-.  nep - nonlinear eigenvalue solver
+.  nep - the nonlinear eigensolver context
 
    Output Parameter:
-.  pep - the polynomial eigensolver object
+.  pep - the polynomial eigensolver context
 
    Level: advanced
 
-.seealso: NEPInterpolSetPEP()
+.seealso: [](ch:nep), `NEPINTERPOL`, `NEPInterpolSetPEP()`
 @*/
 PetscErrorCode NEPInterpolGetPEP(NEP nep,PEP *pep)
 {
@@ -462,6 +463,22 @@ static PetscErrorCode NEPDestroy_Interpol(NEP nep)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   NEPINTERPOL - NEPINTERPOL = "interpol" - Solve the nonlinear
+   eigenvalue problem via polynomial interpolation.
+
+   Note:
+   This solver will approximate the nonlinear eigenvalue problem
+   with a polynomial eigenvalue problem and use `PEP` to solve it.
+   This is appropriate in nonlinear problems without singularities
+   and whose eigenvalues are all real. The degree of the polynomial
+   should generally be large, in which case a non-monomial representation
+   such as Chebyshev should be used {cite:p}`Kre14`.
+
+   Level: beginner
+
+.seealso: [](ch:nep), `NEP`, `NEPType`, `NEPSetType()`, `NEPSLPGetEPS()`, `NEPSetTwoSided()`, `NEPSLPGetEPSLeft()`
+M*/
 SLEPC_EXTERN PetscErrorCode NEPCreate_Interpol(NEP nep)
 {
   NEP_INTERPOL   *ctx;
@@ -470,7 +487,7 @@ SLEPC_EXTERN PetscErrorCode NEPCreate_Interpol(NEP nep)
   PetscCall(PetscNew(&ctx));
   nep->data   = (void*)ctx;
   ctx->maxdeg = 5;
-  ctx->tol    = PETSC_DEFAULT;
+  ctx->tol    = PETSC_DETERMINE;
 
   nep->ops->solve          = NEPSolve_Interpol;
   nep->ops->setup          = NEPSetUp_Interpol;
