@@ -10,8 +10,8 @@
 /*
    Private header for Deflation in NEP
 */
-#if !defined(SLEPC_NEPDEFL_H)
-#define SLEPC_NEPDEFL_H
+
+#pragma once
 
 # define MAX_MINIDX 1
 
@@ -98,7 +98,6 @@ typedef struct {
   PetscInt    n;
 } NEP_DEF_PCSHELL;
 #endif
-#endif
 
 SLEPC_INTERN PetscErrorCode NEPDeflationCopyToExtendedVec(NEP_EXT_OP,Vec,PetscScalar*,Vec,PetscBool);
 SLEPC_INTERN PetscErrorCode NEPDeflationReset(NEP_EXT_OP);
