@@ -33,40 +33,44 @@ PetscErrorCode PEPMonitor(PEP pep,PetscInt it,PetscInt nconv,PetscScalar *eigr,P
    Logically Collective
 
    Input Parameters:
-+  pep     - eigensolver context obtained from PEPCreate()
-.  monitor - pointer to function (if this is NULL, it turns off monitoring), see PEPMonitorFn
-.  mctx    - [optional] context for private data for the
-             monitor routine (use NULL if no context is desired)
--  monitordestroy - [optional] routine that frees monitor context (may be NULL),
-             see PetscCtxDestroyFn for the calling sequence
++  pep            - the polynomial eigensolver context
+.  monitor        - pointer to function (if this is `NULL`, it turns off monitoring),
+                    see `PEPMonitorFn`
+.  mctx           - [optional] context for private data for the monitor routine
+                    (use `NULL` if no context is desired)
+-  monitordestroy - [optional] routine that frees monitor context (may be `NULL`),
+                    see `PetscCtxDestroyFn` for the calling sequence
 
    Options Database Keys:
-+    -pep_monitor        - print only the first error estimate
-.    -pep_monitor_all    - print error estimates at each iteration
-.    -pep_monitor_conv   - print the eigenvalue approximations only when
-      convergence has been reached
-.    -pep_monitor draw::draw_lg - sets line graph monitor for the first unconverged
-      approximate eigenvalue
-.    -pep_monitor_all draw::draw_lg - sets line graph monitor for all unconverged
-      approximate eigenvalues
-.    -pep_monitor_conv draw::draw_lg - sets line graph monitor for convergence history
--    -pep_monitor_cancel - cancels all monitors that have been hardwired into
-      a code by calls to PEPMonitorSet(), but does not cancel those set via
-      the options database.
++  -pep_monitor                    - print only the first error estimate
+.  -pep_monitor_all                - print error estimates at each iteration
+.  -pep_monitor_conv               - print the eigenvalue approximations only when
+                                     convergence has been reached
+.  -pep_monitor draw::draw_lg      - sets line graph monitor for the first unconverged
+                                     approximate eigenvalue
+.  -pep_monitor_all draw::draw_lg  - sets line graph monitor for all unconverged
+                                     approximate eigenvalues
+.  -pep_monitor_conv draw::draw_lg - sets line graph monitor for convergence history
+-  -pep_monitor_cancel             - cancels all monitors that have been hardwired into
+                                     a code by calls to `PEPMonitorSet()`, but does not cancel
+                                     those set via the options database.
 
    Notes:
-   The options database option -pep_monitor and related options are the easiest way
-   to turn on PEP iteration monitoring.
+   The options database option `-pep_monitor` and related options are the easiest way
+   to turn on `PEP` iteration monitoring.
 
-   PEPMonitorRegister() provides a way to associate an options database key with PEP
+   `PEPMonitorRegister()` provides a way to associate an options database key with `PEP`
    monitor function.
 
-   Several different monitoring routines may be set by calling PEPMonitorSet() multiple
+   Several different monitoring routines may be set by calling `PEPMonitorSet()` multiple
    times; all will be called in the order in which they were set.
 
+   Fortran Note:
+   Only a single monitor function can be set for each `PEP` object.
+
    Level: intermediate
 
-.seealso: PEPMonitorFirst(), PEPMonitorAll(), PEPMonitorCancel()
+.seealso: [](ch:pep), `PEPMonitorFirst()`, `PEPMonitorAll()`, `PEPMonitorConverged()`, `PEPMonitorFirstDrawLG()`, `PEPMonitorAllDrawLG()`, `PEPMonitorConvergedDrawLG()`, `PEPMonitorCancel()`
 @*/
 PetscErrorCode PEPMonitorSet(PEP pep,PEPMonitorFn *monitor,void *mctx,PetscCtxDestroyFn *monitordestroy)
 {
@@ -87,21 +91,20 @@ PetscErrorCode PEPMonitorSet(PEP pep,PEPMonitorFn *monitor,void *mctx,PetscCtxDe
 }
 
 /*@
-   PEPMonitorCancel - Clears all monitors for a PEP object.
+   PEPMonitorCancel - Clears all monitors for a `PEP` object.
 
    Logically Collective
 
-   Input Parameters:
-.  pep - eigensolver context obtained from PEPCreate()
+   Input Parameter:
+.  pep - the polynomial eigensolver context
 
    Options Database Key:
-.    -pep_monitor_cancel - Cancels all monitors that have been hardwired
-      into a code by calls to PEPMonitorSet(),
-      but does not cancel those set via the options database.
+.  -pep_monitor_cancel - cancels all monitors that have been hardwired into a code by calls to
+                         `PEPMonitorSet()`, but does not cancel those set via the options database.
 
    Level: intermediate
 
-.seealso: PEPMonitorSet()
+.seealso: [](ch:pep), `PEPMonitorSet()`
 @*/
 PetscErrorCode PEPMonitorCancel(PEP pep)
 {
@@ -118,19 +121,19 @@ PetscErrorCode PEPMonitorCancel(PEP pep)
 
 /*@C
    PEPGetMonitorContext - Gets the monitor context, as set by
-   PEPMonitorSet() for the FIRST monitor only.
+   `PEPMonitorSet()` for the FIRST monitor only.
 
    Not Collective
 
    Input Parameter:
-.  pep - eigensolver context obtained from PEPCreate()
+.  pep - the polynomial eigensolver context
 
    Output Parameter:
 .  ctx - monitor context
 
    Level: intermediate
 
-.seealso: PEPMonitorSet(), PEPDefaultMonitor()
+.seealso: [](ch:pep), `PEPMonitorSet()`
 @*/
 PetscErrorCode PEPGetMonitorContext(PEP pep,void *ctx)
 {
@@ -168,7 +171,7 @@ static PetscErrorCode PEPMonitorGetTrueEig(PEP pep,PetscScalar *er,PetscScalar *
    Collective
 
    Input Parameters:
-+  pep    - polynomial eigensolver context
++  pep    - the polynomial eigensolver context
 .  its    - iteration number
 .  nconv  - number of converged eigenpairs so far
 .  eigr   - real part of the eigenvalues
@@ -178,13 +181,17 @@ static PetscErrorCode PEPMonitorGetTrueEig(PEP pep,PetscScalar *er,PetscScalar *
 -  vf     - viewer and format for monitoring
 
    Options Database Key:
-.  -pep_monitor - activates PEPMonitorFirst()
+.  -pep_monitor - activates `PEPMonitorFirst()`
+
+   Note:
+   This is not called directly by users, rather one calls `PEPMonitorSet()`, with this
+   function as an argument, to cause the monitor to be used during the `PEP` solve.
 
    Level: intermediate
 
-.seealso: PEPMonitorSet(), PEPMonitorAll(), PEPMonitorConverged()
+.seealso: [](ch:pep), `PEPMonitorSet()`, `PEPMonitorAll()`, `PEPMonitorConverged()`
 @*/
-PetscErrorCode PEPMonitorFirst(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
+PetscErrorCode PEPMonitorFirst(PEP pep,PetscInt its,PetscInt nconv,PetscScalar eigr[],PetscScalar eigi[],PetscReal errest[],PetscInt nest,PetscViewerAndFormat *vf)
 {
   PetscScalar    er,ei;
   PetscViewer    viewer = vf->viewer;
@@ -221,7 +228,7 @@ PetscErrorCode PEPMonitorFirst(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *
    Collective
 
    Input Parameters:
-+  pep    - polynomial eigensolver context
++  pep    - the polynomial eigensolver context
 .  its    - iteration number
 .  nconv  - number of converged eigenpairs so far
 .  eigr   - real part of the eigenvalues
@@ -231,13 +238,17 @@ PetscErrorCode PEPMonitorFirst(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *
 -  vf     - viewer and format for monitoring
 
    Options Database Key:
-.  -pep_monitor_all - activates PEPMonitorAll()
+.  -pep_monitor_all - activates `PEPMonitorAll()`
+
+   Note:
+   This is not called directly by users, rather one calls `PEPMonitorSet()`, with this
+   function as an argument, to cause the monitor to be used during the `PEP` solve.
 
    Level: intermediate
 
-.seealso: PEPMonitorSet(), PEPMonitorFirst(), PEPMonitorConverged()
+.seealso: [](ch:pep), `PEPMonitorSet()`, `PEPMonitorFirst()`, `PEPMonitorConverged()`
 @*/
-PetscErrorCode PEPMonitorAll(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
+PetscErrorCode PEPMonitorAll(PEP pep,PetscInt its,PetscInt nconv,PetscScalar eigr[],PetscScalar eigi[],PetscReal errest[],PetscInt nest,PetscViewerAndFormat *vf)
 {
   PetscInt       i;
   PetscScalar    er,ei;
@@ -276,7 +287,7 @@ PetscErrorCode PEPMonitorAll(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *ei
    Collective
 
    Input Parameters:
-+  pep    - polynomial eigensolver context
++  pep    - the polynomial eigensolver context
 .  its    - iteration number
 .  nconv  - number of converged eigenpairs so far
 .  eigr   - real part of the eigenvalues
@@ -286,13 +297,17 @@ PetscErrorCode PEPMonitorAll(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *ei
 -  vf     - viewer and format for monitoring
 
    Options Database Key:
-.  -pep_monitor_conv - activates PEPMonitorConverged()
+.  -pep_monitor_conv - activates `PEPMonitorConverged()`
+
+   Note:
+   This is not called directly by users, rather one calls `PEPMonitorSet()`, with this
+   function as an argument, to cause the monitor to be used during the `PEP` solve.
 
    Level: intermediate
 
-.seealso: PEPMonitorSet(), PEPMonitorFirst(), PEPMonitorAll()
+.seealso: [](ch:pep), `PEPMonitorSet()`, `PEPMonitorFirst()`, `PEPMonitorAll()`
 @*/
-PetscErrorCode PEPMonitorConverged(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
+PetscErrorCode PEPMonitorConverged(PEP pep,PetscInt its,PetscInt nconv,PetscScalar eigr[],PetscScalar eigi[],PetscReal errest[],PetscInt nest,PetscViewerAndFormat *vf)
 {
   PetscInt       i;
   PetscScalar    er,ei;
@@ -358,7 +373,7 @@ PetscErrorCode PEPMonitorConvergedDestroy(PetscViewerAndFormat **vf)
    Collective
 
    Input Parameters:
-+  pep    - polynomial eigensolver context
++  pep    - the polynomial eigensolver context
 .  its    - iteration number
 .  nconv  - number of converged eigenpairs so far
 .  eigr   - real part of the eigenvalues
@@ -368,13 +383,19 @@ PetscErrorCode PEPMonitorConvergedDestroy(PetscViewerAndFormat **vf)
 -  vf     - viewer and format for monitoring
 
    Options Database Key:
-.  -pep_monitor draw::draw_lg - activates PEPMonitorFirstDrawLG()
+.  -pep_monitor draw::draw_lg - activates `PEPMonitorFirstDrawLG()`
+
+   Notes:
+   This is not called directly by users, rather one calls `PEPMonitorSet()`, with this
+   function as an argument, to cause the monitor to be used during the `PEP` solve.
+
+   Call `PEPMonitorFirstDrawLGCreate()` to create the context used with this monitor.
 
    Level: intermediate
 
-.seealso: PEPMonitorSet()
+.seealso: [](ch:pep), `PEPMonitorSet()`, `PEPMonitorFirstDrawLGCreate()`
 @*/
-PetscErrorCode PEPMonitorFirstDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
+PetscErrorCode PEPMonitorFirstDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscScalar eigr[],PetscScalar eigi[],PetscReal errest[],PetscInt nest,PetscViewerAndFormat *vf)
 {
   PetscViewer    viewer = vf->viewer;
   PetscDrawLG    lg;
@@ -419,7 +440,7 @@ PetscErrorCode PEPMonitorFirstDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscSc
 
    Level: intermediate
 
-.seealso: PEPMonitorSet()
+.seealso: [](ch:pep), `PEPMonitorSet()`
 @*/
 PetscErrorCode PEPMonitorFirstDrawLGCreate(PetscViewer viewer,PetscViewerFormat format,void *ctx,PetscViewerAndFormat **vf)
 {
@@ -437,7 +458,7 @@ PetscErrorCode PEPMonitorFirstDrawLGCreate(PetscViewer viewer,PetscViewerFormat
    Collective
 
    Input Parameters:
-+  pep    - polynomial eigensolver context
++  pep    - the polynomial eigensolver context
 .  its    - iteration number
 .  nconv  - number of converged eigenpairs so far
 .  eigr   - real part of the eigenvalues
@@ -447,13 +468,19 @@ PetscErrorCode PEPMonitorFirstDrawLGCreate(PetscViewer viewer,PetscViewerFormat
 -  vf     - viewer and format for monitoring
 
    Options Database Key:
-.  -pep_monitor_all draw::draw_lg - activates PEPMonitorAllDrawLG()
+.  -pep_monitor_all draw::draw_lg - activates `PEPMonitorAllDrawLG()`
+
+   Notes:
+   This is not called directly by users, rather one calls `PEPMonitorSet()`, with this
+   function as an argument, to cause the monitor to be used during the `PEP` solve.
+
+   Call `PEPMonitorAllDrawLGCreate()` to create the context used with this monitor.
 
    Level: intermediate
 
-.seealso: PEPMonitorSet()
+.seealso: [](ch:pep), `PEPMonitorSet()`, `PEPMonitorAllDrawLGCreate()`
 @*/
-PetscErrorCode PEPMonitorAllDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
+PetscErrorCode PEPMonitorAllDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscScalar eigr[],PetscScalar eigi[],PetscReal errest[],PetscInt nest,PetscViewerAndFormat *vf)
 {
   PetscViewer    viewer = vf->viewer;
   PetscDrawLG    lg;
@@ -501,7 +528,7 @@ PetscErrorCode PEPMonitorAllDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscScal
 
    Level: intermediate
 
-.seealso: PEPMonitorSet()
+.seealso: [](ch:pep), `PEPMonitorSet()`
 @*/
 PetscErrorCode PEPMonitorAllDrawLGCreate(PetscViewer viewer,PetscViewerFormat format,void *ctx,PetscViewerAndFormat **vf)
 {
@@ -519,7 +546,7 @@ PetscErrorCode PEPMonitorAllDrawLGCreate(PetscViewer viewer,PetscViewerFormat fo
    Collective
 
    Input Parameters:
-+  pep    - polynomial eigensolver context
++  pep    - the polynomial eigensolver context
 .  its    - iteration number
 .  nconv  - number of converged eigenpairs so far
 .  eigr   - real part of the eigenvalues
@@ -529,13 +556,19 @@ PetscErrorCode PEPMonitorAllDrawLGCreate(PetscViewer viewer,PetscViewerFormat fo
 -  vf     - viewer and format for monitoring
 
    Options Database Key:
-.  -pep_monitor_conv draw::draw_lg - activates PEPMonitorConvergedDrawLG()
+.  -pep_monitor_conv draw::draw_lg - activates `PEPMonitorConvergedDrawLG()`
+
+   Notes:
+   This is not called directly by users, rather one calls `PEPMonitorSet()`, with this
+   function as an argument, to cause the monitor to be used during the `PEP` solve.
+
+   Call `PEPMonitorConvergedDrawLGCreate()` to create the context used with this monitor.
 
    Level: intermediate
 
-.seealso: PEPMonitorSet()
+.seealso: [](ch:pep), `PEPMonitorSet()`, `PEPMonitorConvergedDrawLGCreate()`
 @*/
-PetscErrorCode PEPMonitorConvergedDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
+PetscErrorCode PEPMonitorConvergedDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscScalar eigr[],PetscScalar eigi[],PetscReal errest[],PetscInt nest,PetscViewerAndFormat *vf)
 {
   PetscViewer      viewer = vf->viewer;
   PetscDrawLG      lg;
@@ -577,7 +610,7 @@ PetscErrorCode PEPMonitorConvergedDrawLG(PEP pep,PetscInt its,PetscInt nconv,Pet
 
    Level: intermediate
 
-.seealso: PEPMonitorSet()
+.seealso: [](ch:pep), `PEPMonitorSet()`
 @*/
 PetscErrorCode PEPMonitorConvergedDrawLGCreate(PetscViewer viewer,PetscViewerFormat format,void *ctx,PetscViewerAndFormat **vf)
 {
