@@ -20,13 +20,13 @@ SLEPC_EXTERN PetscErrorCode PEPCreate_CISS(PEP);
 #endif
 
 /*@C
-   PEPRegisterAll - Registers all the solvers in the PEP package.
+   PEPRegisterAll - Registers all the solvers in the `PEP` package.
 
    Not Collective
 
    Level: advanced
 
-.seealso: PEPRegister()
+.seealso: [](ch:pep), `PEPRegister()`
 @*/
 PetscErrorCode PEPRegisterAll(void)
 {
@@ -45,13 +45,13 @@ PetscErrorCode PEPRegisterAll(void)
 }
 
 /*@C
-  PEPMonitorRegisterAll - Registers all the monitors in the PEP package.
+  PEPMonitorRegisterAll - Registers all the monitors in the `PEP` package.
 
   Not Collective
 
   Level: advanced
 
-.seealso: PEPMonitorRegister()
+.seealso: [](ch:pep), `PEPMonitorRegister()`
 @*/
 PetscErrorCode PEPMonitorRegisterAll(void)
 {
